@@ -3,7 +3,7 @@
  *
  * Copyright (C) 1999 Dave Cole
  * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
- * Copyright (C) 2005 Roland Clobus <rclobus@bigfoot.com>
+ * Copyright (C) 2005,2010 Roland Clobus <rclobus@rclobus.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,11 +36,10 @@
  *
  */
 
-#define DEVEL_CARD 222
-
 typedef struct resource_values_s {
 	float value[NO_RESOURCE];
 	MaritimeInfo info;
+	gint ports[NO_RESOURCE];
 } resource_values_t;
 
 static int quote_num;
@@ -49,9 +48,13 @@ static int quote_num;
 static gboolean discard_starting;
 
 /* things we can buy, in the order that we want them. */
-static BuildType build_preferences[] = { BUILD_CITY, BUILD_SETTLEMENT,
-	BUILD_ROAD, DEVEL_CARD
-};
+typedef enum {
+	BUY_CITY,
+	BUY_SETTLEMENT,
+	BUY_ROAD,
+	BUY_DEVEL_CARD,
+	BUY_LAST
+} BuyType;
 
 /*
  * Forward declarations
@@ -69,6 +72,7 @@ static Node *best_settlement_spot(gboolean during_setup,
 				  const resource_values_t * resval);
 
 static int places_can_build_settlement(void);
+static gint determine_monopoly_resource(void);
 
 /*
  * Functions to keep track of what nodes we've visited
@@ -160,16 +164,16 @@ static gboolean can_pay_for(const gint assets[NO_RESOURCE],
 }
 
 /* How much does this cost to build? */
-static const gint *cost_of(BuildType bt)
+static const gint *cost_of(BuyType bt)
 {
 	switch (bt) {
-	case BUILD_CITY:
+	case BUY_CITY:
 		return cost_upgrade_settlement();
-	case BUILD_SETTLEMENT:
+	case BUY_SETTLEMENT:
 		return cost_settlement();
-	case BUILD_ROAD:
+	case BUY_ROAD:
 		return cost_road();
-	case DEVEL_CARD:
+	case BUY_DEVEL_CARD:
 		return cost_development();
 	default:
 		g_assert(0);
@@ -180,7 +184,7 @@ static const gint *cost_of(BuildType bt)
 /*
  * Do I have the resources to buy this, is it available, and do I want it?
  */
-static gboolean should_buy(const gint assets[NO_RESOURCE], BuildType bt,
+static gboolean should_buy(const gint assets[NO_RESOURCE], BuyType bt,
 			   const resource_values_t * resval,
 			   gint need[NO_RESOURCE])
 {
@@ -188,19 +192,19 @@ static gboolean should_buy(const gint assets[NO_RESOURCE], BuildType bt,
 		return FALSE;
 
 	switch (bt) {
-	case BUILD_CITY:
+	case BUY_CITY:
 		return (stock_num_cities() > 0 &&
 			best_city_spot(resval) != NULL);
-	case BUILD_SETTLEMENT:
+	case BUY_SETTLEMENT:
 		return (stock_num_settlements() > 0 &&
 			best_settlement_spot(FALSE, resval) != NULL);
-	case BUILD_ROAD:
+	case BUY_ROAD:
 		/* don't sprawl :) */
 		return (stock_num_roads() > 0 &&
 			places_can_build_settlement() <= 2 &&
 			(best_road_spot(resval) != NULL ||
 			 best_road_to_road(resval) != NULL));
-	case DEVEL_CARD:
+	case BUY_DEVEL_CARD:
 		return (stock_num_develop() > 0 && can_buy_develop());
 	default:
 		/* xxx bridge, ship */
@@ -213,7 +217,7 @@ static gboolean should_buy(const gint assets[NO_RESOURCE], BuildType bt,
  * can be negative if I can't afford it.
  */
 static void leftover_resources(const gint assets[NO_RESOURCE],
-			       BuildType bt, gint need[NO_RESOURCE])
+			       BuyType bt, gint need[NO_RESOURCE])
 {
 	gint i;
 	const gint *cost = cost_of(bt);
@@ -304,7 +308,7 @@ static void reevaluate_iterator(Node * n, void *rock)
 			if (n->type == BUILD_CITY)
 				mult = 2.0;
 
-			if (h && h->terrain < NO_RESOURCE) {
+			if (h && h->terrain < DESERT_TERRAIN) {
 				produce[h->terrain] +=
 				    mult *
 				    default_score_resource(h->terrain) *
@@ -348,6 +352,15 @@ static void reevaluate_resources(resource_values_t * outval)
 	 */
 	map_maritime_info(callbacks.get_map(), &outval->info,
 			  my_player_num());
+
+	for (i = 0; i < NO_RESOURCE; i++) {
+		if (outval->info.specific_resource[i])
+			outval->ports[i] = 2;
+		else if (outval->info.any_resource)
+			outval->ports[i] = 3;
+		else
+			outval->ports[i] = 4;
+	}
 }
 
 
@@ -612,7 +625,7 @@ static Edge *traverse_out(Node * n, node_seen_set_t * set, float *score,
 static Edge *best_road_to_road_spot(Node * n, float *score,
 				    const resource_values_t * resval)
 {
-	int bscore = -1.0;
+	float bscore = -1.0;
 	Edge *best = NULL;
 	int i, j;
 
@@ -634,14 +647,14 @@ static Edge *best_road_to_road_spot(Node * n, float *score,
 
 					if (can_road_be_built
 					    (e2, my_player_num())) {
-						float score =
+						float nscore =
 						    score_node(other_node
 							       (e2,
 								othernode),
 							       0, resval);
 
-						if (score > bscore) {
-							bscore = score;
+						if (nscore > bscore) {
+							bscore = nscore;
 							best = e;
 						}
 					}
@@ -871,13 +884,14 @@ static int resource_desire(gint assets[NO_RESOURCE],
 			   const resource_values_t * resval)
 {
 	int i;
+	BuyType bt;
 	int res = NO_RESOURCE;
 	float value = 0.0;
 	gint need[NO_RESOURCE];
 
 	/* do i need just 1 more for something? */
-	for (i = 0; i < G_N_ELEMENTS(build_preferences); i++) {
-		if (should_buy(assets, build_preferences[i], resval, need))
+	for (bt = 0; bt < BUY_LAST; bt++) {
+		if (should_buy(assets, bt, resval, need))
 			continue;
 		res = which_one(need);
 		if (res == NO_RESOURCE || resval->value[res] == 0)
@@ -1007,19 +1021,16 @@ static void greedy_setup_road(void)
  */
 static gboolean find_optimal_trade(gint assets[NO_RESOURCE],
 				   const resource_values_t * resval,
-				   gint ports[NO_RESOURCE],
 				   gint * amount,
 				   Resource * trade_away,
 				   Resource * want_resource)
 {
-	int i;
 	Resource res = NO_RESOURCE;
 	Resource temp;
 	gint need[NO_RESOURCE];
-	BuildType bt = BUILD_NONE;
+	BuyType bt;
 
-	for (i = 0; i < G_N_ELEMENTS(build_preferences); i++) {
-		bt = build_preferences[i];
+	for (bt = 0; bt < BUY_LAST; bt++) {
 
 		/* If we should buy something, why haven't we bought it? */
 		if (should_buy(assets, bt, resval, need))
@@ -1038,8 +1049,8 @@ static gboolean find_optimal_trade(gint assets[NO_RESOURCE],
 		for (temp = 0; temp < NO_RESOURCE; temp++) {
 			if (temp == res)
 				continue;
-			if (need[temp] > ports[temp]) {
-				*amount = ports[temp];
+			if (need[temp] > resval->ports[temp]) {
+				*amount = resval->ports[temp];
 				*trade_away = temp;
 				*want_resource = res;
 				return TRUE;
@@ -1063,31 +1074,18 @@ static gboolean will_do_maritime_trade(gint assets[NO_RESOURCE],
 				       Resource * trade_away,
 				       Resource * want_resource)
 {
-	MaritimeInfo info;
 	Resource res, want, discard;
-	gint ports[NO_RESOURCE];
-
-	map_maritime_info(callbacks.get_map(), &info, my_player_num());
-
-	for (res = 0; res < NO_RESOURCE; res++) {
-		if (info.specific_resource[res])
-			ports[res] = 2;
-		else if (info.any_resource)
-			ports[res] = 3;
-		else
-			ports[res] = 4;
-	}
 
 	/* See if we can trade at all. */
 	for (res = 0; res < NO_RESOURCE; res++) {
-		if (assets[res] >= ports[res])
+		if (assets[res] >= resval->ports[res])
 			break;
 	}
 	if (res == NO_RESOURCE)
 		return FALSE;
 
 	/* See if we can do a single trade that allows us to buy something. */
-	if (find_optimal_trade(assets, resval, ports, amount, trade_away,
+	if (find_optimal_trade(assets, resval, amount, trade_away,
 			       want_resource))
 		return TRUE;
 
@@ -1106,16 +1104,16 @@ static gboolean will_do_maritime_trade(gint assets[NO_RESOURCE],
 	for (res = 0; res < NO_RESOURCE; res++) {
 		if (res == want)
 			continue;
-		if (assets[res] > ports[res] &&
+		if (assets[res] > resval->ports[res] &&
 		    (discard == NO_RESOURCE
-		     || ports[discard] > ports[res]))
+		     || resval->ports[discard] > resval->ports[res]))
 			discard = res;
 	}
 
 	if (discard != NO_RESOURCE) {
 		*trade_away = discard;
 		*want_resource = want;
-		*amount = ports[discard];
+		*amount = resval->ports[discard];
 		return TRUE;
 	}
 
@@ -1128,7 +1126,7 @@ static gboolean will_do_maritime_trade(gint assets[NO_RESOURCE],
  */
 static gboolean will_play_development_card(DevelType cardtype)
 {
-	gint amount, cards, i;
+	gint amount, i;
 
 	if (is_victory_card(cardtype)) {
 		return TRUE;
@@ -1152,13 +1150,7 @@ static gboolean will_play_development_card(DevelType cardtype)
 			break;
 		return TRUE;
 	case DEVEL_MONOPOLY:
-		/* don't unless there are enough cards out */
-		for (i = 0, cards = 0; i < num_players(); i++)
-			if (i != my_player_num())
-				cards += player_get_num_resource(i);
-		if (cards >= 6)
-			return TRUE;
-		break;
+		return determine_monopoly_resource() != NO_RESOURCE;
 	default:
 		break;
 	}
@@ -1176,6 +1168,26 @@ static void greedy_turn(void)
 	int i;
 	gint need[NO_RESOURCE], assets[NO_RESOURCE];
 
+	/* play soldier card before the turn when an own resource is blocked */
+	Hex *hex = map_robber_hex(callbacks.get_map());
+	if (hex && !have_rolled_dice() && can_play_any_develop()) {
+		const DevelDeck *deck = get_devel_deck();
+		for (i = 0; i < deck->num_cards; i++) {
+			DevelType cardtype = deck_card_type(deck, i);
+			if (cardtype == DEVEL_SOLDIER
+			    && can_play_develop(i)) {
+				int j;
+				for (j = 0; j < 6; j++) {
+					if ((hex->nodes[j]->owner ==
+					     my_player_num())) {
+						cb_play_develop(i);
+						return;
+					}
+				}
+			}
+		}
+	}
+
 	if (!have_rolled_dice()) {
 		cb_roll();
 		return;
@@ -1189,7 +1201,7 @@ static void greedy_turn(void)
 	reevaluate_resources(&resval);
 
 	/* if can then buy city */
-	if (should_buy(assets, BUILD_CITY, &resval, need)) {
+	if (should_buy(assets, BUY_CITY, &resval, need)) {
 
 		Node *n = best_city_spot(&resval);
 		if (n != NULL) {
@@ -1199,7 +1211,7 @@ static void greedy_turn(void)
 	}
 
 	/* if can then buy settlement */
-	if (should_buy(assets, BUILD_SETTLEMENT, &resval, need)) {
+	if (should_buy(assets, BUY_SETTLEMENT, &resval, need)) {
 
 		Node *n = best_settlement_spot(FALSE, &resval);
 		if (n != NULL) {
@@ -1209,7 +1221,7 @@ static void greedy_turn(void)
 
 	}
 
-	if (should_buy(assets, BUILD_ROAD, &resval, need)) {
+	if (should_buy(assets, BUY_ROAD, &resval, need)) {
 
 		Edge *e = best_road_spot(&resval);
 
@@ -1224,7 +1236,7 @@ static void greedy_turn(void)
 	}
 
 	/* if we can buy a development card and there are some left */
-	if (should_buy(assets, DEVEL_CARD, &resval, need)) {
+	if (should_buy(assets, BUY_DEVEL_CARD, &resval, need)) {
 		cb_buy_develop();
 		return;
 	}
@@ -1295,78 +1307,112 @@ static void greedy_turn(void)
 	} while(0)
 
 static const char *chat_turn_start[] = {
+	/* AI chat at the start of the turn */
 	N_("Ok, let's go!"),
+	/* AI chat at the start of the turn */
 	N_("I'll beat you all now! ;)"),
+	/* AI chat at the start of the turn */
 	N_("Now for another try..."),
 };
 
 static const char *chat_receive_one[] = {
+	/* AI chat when one resource is received */
 	N_("At least I get something..."),
+	/* AI chat when one resource is received */
 	N_("One is better than none..."),
 };
 
 static const char *chat_receive_many[] = {
+	/* AI chat when more than one resource is received */
 	N_("Wow!"),
+	/* AI chat when more than one resource is received */
 	N_("Ey, I'm becoming rich ;)"),
+	/* AI chat when more than one resource is received */
 	N_("This is really a good year!"),
 };
 
 static const char *chat_other_receive_many[] = {
+	/* AI chat when other players receive more than one resource */
 	N_("You really don't deserve that much!"),
+	/* AI chat when other players receive more than one resource */
 	N_("You don't know what to do with that many resources ;)"),
+	/* AI chat when other players receive more than one resource */
 	N_("Ey, wait for my robber and lose all this again!"),
 };
 
 static const char *chat_self_moved_robber[] = {
+	/* AI chat when it moves the robber */
 	N_("Hehe!"),
+	/* AI chat when it moves the robber */
 	N_("Go, robber, go!"),
 };
 
 static const char *chat_moved_robber_to_me[] = {
+	/* AI chat when the robber is moved to it */
 	N_("You bastard!"),
+	/* AI chat when the robber is moved to it */
 	N_("Can't you move that robber somewhere else?!"),
+	/* AI chat when the robber is moved to it */
 	N_("Why always me??"),
 };
 
 static const char *chat_discard_self[] = {
+	/* AI chat when it must discard resources */
 	N_("Oh no!"),
+	/* AI chat when it must discard resources */
 	N_("Grrr!"),
+	/* AI chat when it must discard resources */
 	N_("Who the hell rolled that 7??"),
+	/* AI chat when it must discard resources */
 	N_("Why always me?!?"),
 };
 
 static const char *chat_discard_other[] = {
+	/* AI chat when other players must discard */
 	N_("Say good bye to your cards... :)"),
+	/* AI chat when other players must discard */
 	N_("*evilgrin*"),
+	/* AI chat when other players must discard */
 	N_("/me says farewell to your cards ;)"),
+	/* AI chat when other players must discard */
 	N_("That's the price for being rich... :)"),
 };
 
 static const char *chat_stole_from_me[] = {
+	/* AI chat when someone steals from it */
 	N_("Ey! Where's that card gone?"),
+	/* AI chat when someone steals from it */
 	N_("Thieves! Thieves!!"),
+	/* AI chat when someone steals from it */
 	N_("Wait for my revenge..."),
 };
 
 static const char *chat_monopoly_other[] = {
+	/* AI chat when someone plays the monopoly card */
 	N_("Oh no :("),
+	/* AI chat when someone plays the monopoly card */
 	N_("Must this happen NOW??"),
+	/* AI chat when someone plays the monopoly card */
 	N_("Args"),
 };
 
 static const char *chat_largestarmy_self[] = {
+	/* AI chat when it has the largest army */
 	N_("Hehe, my soldiers rule!"),
 };
 
 static const char *chat_largestarmy_other[] = {
+	/* AI chat when another player that the largest army */
 	N_("First robbing us, then grabbing the points..."),
 };
 
 static const char *chat_longestroad_self[] = {
+	/* AI chat when it has the longest road */
 	N_("See that road!"),
 };
 
 static const char *chat_longestroad_other[] = {
+	/* AI chat when another player has the longest road */
 	N_("Pf, you won't win with roads alone..."),
 };
 
@@ -1571,14 +1617,25 @@ static gint other_players_have(Resource res)
 	return game_resources() - get_bank()[res] - resource_asset(res);
 }
 
-static void greedy_monopoly(void)
+static float monopoly_wildcard_value(const resource_values_t * resval,
+				     const gint assets[NO_RESOURCE],
+				     gint resource)
+{
+	return (float) (other_players_have(resource) +
+			assets[resource]) / resval->ports[resource];
+}
+
+/** Determine the best resource to get with a monopoly card.
+ * @return the resource
+*/
+static gint determine_monopoly_resource(void)
 {
 	gint assets[NO_RESOURCE];
 	int i;
-	int r, best;
+	gint most_desired;
+	gint most_wildcards;
 	resource_values_t resval;
 
-	ai_wait();
 	for (i = 0; i < NO_RESOURCE; i++)
 		assets[i] = resource_asset(i);
 
@@ -1586,26 +1643,35 @@ static void greedy_monopoly(void)
 	reevaluate_resources(&resval);
 
 	/* try to get something we need */
-	while (TRUE) {
-		r = resource_desire(assets, &resval);
-		if (r == NO_RESOURCE)
-			break;
-		if (other_players_have(r) > 0) {
-			cb_choose_monopoly(r);
-			return;
-		}
-		resval.value[r] = 0;
+	most_desired = resource_desire(assets, &resval);
+
+	/* try to get the optimal maritime trade. */
+	most_wildcards = 0;
+	for (i = 1; i < NO_RESOURCE; i++) {
+		if (monopoly_wildcard_value(&resval, assets, i) >
+		    monopoly_wildcard_value(&resval, assets,
+					    most_wildcards))
+			most_wildcards = i;
 	}
 
-	/* there's nothing we really need, so get what we can get most of. */
-	best = 0;
-	for (r = 1; r < NO_RESOURCE; r++) {
-		if (other_players_have(r) > other_players_have(best))
-			best = r;
+	/* choose the best */
+	if (most_desired != NO_RESOURCE
+	    && other_players_have(most_desired) >
+	    monopoly_wildcard_value(&resval, assets, most_wildcards)) {
+		return most_desired;
+	} else if (monopoly_wildcard_value(&resval, assets, most_wildcards)
+		   >= 1.0) {
+		return most_wildcards;
+	} else {
+		return NO_RESOURCE;
 	}
-	cb_choose_monopoly(best);
 }
 
+static void greedy_monopoly(void)
+{
+	ai_wait();
+	cb_choose_monopoly(determine_monopoly_resource());
+}
 
 /*
  * Of these resources which is least valuable to us
@@ -1642,7 +1708,7 @@ static int least_valuable(gint assets[NO_RESOURCE],
 static int resource_desire_least(gint my_assets[NO_RESOURCE],
 				 resource_values_t * resval)
 {
-	int i;
+	BuyType bt;
 	int res;
 	gint assets[NO_RESOURCE];
 	gint need[NO_RESOURCE];
@@ -1654,8 +1720,7 @@ static int resource_desire_least(gint my_assets[NO_RESOURCE],
 	}
 
 	/* eliminate things we need to build stuff */
-	for (i = 0; i < G_N_ELEMENTS(build_preferences); i++) {
-		BuildType bt = build_preferences[i];
+	for (bt = 0; bt < BUY_LAST; bt++) {
 		if (should_buy(assets, bt, resval, need)) {
 			cost_buy(cost_of(bt), assets);
 		}
@@ -1749,22 +1814,22 @@ static int trade_desired(gint assets[NO_RESOURCE], gint give, gint take,
 
 	for (n = 1; n <= 3; ++n) {
 		/* do i need something more for something? */
-		if (!should_buy(assets, BUILD_CITY, &resval, need)) {
+		if (!should_buy(assets, BUY_CITY, &resval, need)) {
 			if ((res = which_resource(need)) == take
 			    && need[res] == n)
 				break;
 		}
-		if (!should_buy(assets, BUILD_SETTLEMENT, &resval, need)) {
+		if (!should_buy(assets, BUY_SETTLEMENT, &resval, need)) {
 			if ((res = which_resource(need)) == take
 			    && need[res] == n)
 				break;
 		}
-		if (!should_buy(assets, BUILD_ROAD, &resval, need)) {
+		if (!should_buy(assets, BUY_ROAD, &resval, need)) {
 			if ((res = which_resource(need)) == take
 			    && need[res] == n)
 				break;
 		}
-		if (!should_buy(assets, DEVEL_CARD, &resval, need)) {
+		if (!should_buy(assets, BUY_DEVEL_CARD, &resval, need)) {
 			if ((res = which_resource(need)) == take
 			    && need[res] == n)
 				break;
@@ -1905,6 +1970,14 @@ static void greedy_gold_choose(gint gold_num, const gint * bank)
 	for (i = 0; i < gold_num; i++) {
 		reevaluate_resources(&resval);
 
+		/* If the bank has been emptied, don't desire it */
+		gint j;
+		for (j = 0; j < NO_RESOURCE; j++) {
+			if (my_bank[j] == 0) {
+				resval.value[j] = 0;
+			}
+		}
+
 		r1 = resource_desire(assets, &resval);
 		/* If we don't want anything, start emptying the bank */
 		if (r1 == NO_RESOURCE) {
@@ -1936,10 +2009,13 @@ static void greedy_error(const gchar * message)
 
 static void greedy_game_over(gint player_num, G_GNUC_UNUSED gint points)
 {
-	if (player_num == my_player_num())
+	if (player_num == my_player_num()) {
+		/* AI chat when it wins */
 		ai_chat(N_("Yippie!"));
-	else
+	} else {
+		/* AI chat when another player wins */
 		ai_chat(N_("My congratulations"));
+	}
 	cb_disconnect();
 }
 
@@ -2012,7 +2088,7 @@ static void greedy_new_statistics(gint player_num, StatisticType type,
 	}
 }
 
-void greedy_init(G_GNUC_UNUSED int argc, G_GNUC_UNUSED char **argv)
+void greedy_init(void)
 {
 	callbacks.setup = &greedy_setup;
 	callbacks.turn = &greedy_turn;
