@@ -63,7 +63,7 @@ typedef struct {
 	gchar *name;
 	gchar *style;
 	gint num;
-} Viewer;
+} Spectator;
 
 enum callback_mode {
 	MODE_INIT,		/* not connected */
@@ -88,9 +88,14 @@ enum callback_mode {
 
 /* functions to be implemented by front ends */
 struct callbacks {
+	/* This function is called when the client is initializing.  The
+	 * frontend should initialize its libraries and use the command
+	 * line for the default commands. */
+	void (*init_glib_et_al) (int argc, char **argv);
 	/* This function is called when the client is initialized.  The
-	 * frontend should initialize itself now */
-	void (*init) (int argc, char **argv);
+	 * frontend should initialize itself now and process its own 
+	 * command line options. */
+	void (*init) (void);
 	/* Allows the frontend to show a message considering the network
 	 * status, probably in the status bar */
 	void (*network_status) (const gchar * description);
@@ -244,16 +249,16 @@ struct callbacks {
 	 * it has already been done by the client. */
 	void (*new_points) (gint player_num, Points * points,
 			    gboolean added);
-	/* a viewer changed his/her name */
-	void (*viewer_name) (gint viewer_num, const gchar * name);
+	/* a spectator changed his/her name */
+	void (*spectator_name) (gint spectator_num, const gchar * name);
 	/* a player changed his/her name */
 	void (*player_name) (gint player_num, const gchar * name);
 	/* a player changed his/her style */
 	void (*player_style) (gint player_num, const gchar * style);
 	/* a player left the game */
 	void (*player_quit) (gint player_num);
-	/* a viewer left the game */
-	void (*viewer_quit) (gint player_num);
+	/* a spectator left the game */
+	void (*spectator_quit) (gint player_num);
 	/* respond to incoming chat messages */
 	void (*incoming_chat) (gint player_num, const gchar * chat);
 	/* something changed in the bank. */
@@ -284,7 +289,7 @@ extern gboolean color_chat_enabled;
  * changes to the board, etc.  The frontend should NEVER touch any game
  * structures directly (except for reading). */
 void cb_connect(const gchar * server, const gchar * port,
-		const gchar * name, gboolean viewer, const gchar * style);
+		gboolean spectator);
 void cb_disconnect(void);
 void cb_roll(void);
 void cb_build_road(const Edge * edge);
@@ -324,21 +329,21 @@ gboolean can_buy_develop(void);
 gboolean can_play_develop(int card);
 gboolean can_play_any_develop(void);
 Player *player_get(gint num);
-gboolean player_is_viewer(gint num);
-Viewer *viewer_get(gint num);
+gboolean player_is_spectator(gint num);
+Spectator *spectator_get(gint num);
 const gchar *player_name(gint player_num, gboolean word_caps);
 gint player_get_score(gint player_num);
 gint my_player_num(void);
 const gchar *my_player_name(void);
-gboolean my_player_viewer(void);
+gboolean my_player_spectator(void);
 const gchar *my_player_style(void);
 const gchar *player_get_style(gint player_num);
 void player_set_style(gint player_num, const gchar * style);
 gint num_players(void);
 gint current_player(void);
-/** Find the player or viewer with name
+/** Find the player or spectator with name
  *  @param name The name to search for
- *  @return the player/viewer number or -1 if the name was not found
+ *  @return the player/spectator number or -1 if the name was not found
  */
 gint find_player_by_name(const gchar * name);
 gint build_count_edges(void);
@@ -396,7 +401,6 @@ int pirate_count_victims(const Hex * hex, gint * victim_list);
 int robber_count_victims(const Hex * hex, gint * victim_list);
 const gint *get_bank(void);
 const DevelDeck *get_devel_deck(void);
-const gchar *get_devel_name(DevelType type);
 
 /** Returns instructions for the user */
 const gchar *road_building_message(gint build_amount);
