@@ -61,7 +61,6 @@ static gboolean mode_players(StateMachine * sm, gint event);
 static gboolean mode_player_list(StateMachine * sm, gint event);
 static gboolean mode_load_game(StateMachine * sm, gint event);
 static gboolean mode_load_gameinfo(StateMachine * sm, gint event);
-static gboolean mode_start_response(StateMachine * sm, gint event);
 static gboolean mode_setup(StateMachine * sm, gint event);
 static gboolean mode_idle(StateMachine * sm, gint event);
 static gboolean mode_wait_for_robber(StateMachine * sm, gint event);
@@ -1071,12 +1070,11 @@ static gboolean mode_load_game(StateMachine * sm, gint event)
 static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 {
 	gint x, y, pos, owner;
-	static gboolean disconnected = FALSE;
 	static gboolean have_bank = FALSE;
 	static gint devcardidx = -1;
 	static gint numdevcards = -1;
 	gint num_roads, num_bridges, num_ships, num_settlements,
-	    num_cities, num_soldiers, road_len;
+	    num_cities, num_soldiers;
 	gint opnum, opnassets, opncards, opnsoldiers;
 	gboolean pchapel, puniv, pgov, plibr, pmarket, plongestroad,
 	    plargestarmy;
@@ -1109,12 +1107,7 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 	if (sm_recv(sm, "end")) {
 		callback_mode = MODE_WAIT_TURN;	/* allow chatting */
 		callbacks.start_game();
-		if (disconnected) {
-			sm_goto(sm, mode_recovery_wait_start_response);
-		} else {
-			sm_send(sm, "start\n");
-			sm_goto(sm, mode_start_response);
-		}
+		sm_goto(sm, mode_recovery_wait_start_response);
 		return TRUE;
 	}
 	if (sm_recv(sm, "bank %R", tmp_bank)) {
@@ -1157,10 +1150,6 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 		recovery_info.bought_develop = TRUE;
 		return TRUE;
 	}
-	if (sm_recv(sm, "player disconnected")) {
-		disconnected = TRUE;
-		return TRUE;
-	}
 	if (sm_recv(sm, "state %S", &recovery_info.prevstate)) {
 		return TRUE;
 	}
@@ -1194,10 +1183,10 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 		return TRUE;
 	}
 	if (sm_recv
-	    (sm, "playerinfo: %d %d %d %d %d %d %d %d %d %d %d %d %d %d",
+	    (sm, "playerinfo: %d %d %d %d %d %d %d %d %d %d %d %d %d",
 	     &num_roads, &num_bridges, &num_ships, &num_settlements,
-	     &num_cities, &num_soldiers, &road_len, &pchapel, &puniv,
-	     &pgov, &plibr, &pmarket, &plongestroad, &plargestarmy)) {
+	     &num_cities, &num_soldiers, &pchapel, &puniv, &pgov, &plibr,
+	     &pmarket, &plongestroad, &plargestarmy)) {
 		if (num_soldiers) {
 			player_modify_statistic(my_player_num(),
 						STAT_SOLDIERS,
@@ -1324,21 +1313,6 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 	return FALSE;
 }
 
-/* Response to the "start" command
- */
-static gboolean mode_start_response(StateMachine * sm, gint event)
-{
-	sm_state_name(sm, "mode_start_response");
-	if (event != SM_RECV)
-		return FALSE;
-	if (sm_recv(sm, "OK")) {
-		sm_goto(sm, mode_idle);
-		callbacks.network_status(_("Idle"));
-		return TRUE;
-	}
-	return check_other_players(sm);
-}
-
 /*----------------------------------------------------------------------
  * Build command processing
  */
@@ -1427,6 +1401,7 @@ gboolean mode_done_response(StateMachine * sm, gint event)
 static char *setup_msg(void)
 {
 	gchar *msg;
+	gchar *old;
 	const gchar *parts[3];
 	int num_parts;
 	int idx;
@@ -1445,7 +1420,6 @@ static char *setup_msg(void)
 		parts[num_parts++] = _("ship");
 
 	for (idx = 0; idx < num_parts; idx++) {
-		gchar *old;
 		if (idx > 0) {
 			if (idx == num_parts - 1) {
 				old = msg;
@@ -1459,9 +1433,12 @@ static char *setup_msg(void)
 			}
 		}
 		old = msg;
-		msg = g_strdup_printf("%s %s.", msg, parts[idx]);
+		msg = g_strdup_printf("%s %s", msg, parts[idx]);
 		g_free(old);
 	}
+	old = msg;
+	msg = g_strdup_printf("%s.", msg);
+	g_free(old);
 
 	return msg;
 }
@@ -2523,7 +2500,7 @@ static gboolean mode_recovery_wait_start_response(StateMachine * sm,
 			recover_from_disconnect(sm, &recovery_info);
 			return TRUE;
 		}
-		break;
+		return check_other_players(sm);
 	default:
 		break;
 	}
