@@ -54,7 +54,7 @@ static void frontend_start_game(void)
 	gui_set_game_params(get_game_params());
 	set_num_players(num_players());
 	identity_reset();
-	gui_set_show_no_setup_nodes(!player_is_spectator(my_player_num()));
+	gui_set_show_no_setup_nodes(TRUE);
 	frontend_gui_update();
 }
 
