@@ -69,6 +69,7 @@ GtkWidget *chat_build_panel(void)
 	gtk_widget_show(hbox);
 
 	label = gtk_label_new(NULL);
+	/* Label text */
 	gtk_label_set_markup(GTK_LABEL(label), _("<b>Chat</b>"));
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -199,14 +200,14 @@ void chat_player_quit(gint player_num)
 	}
 }
 
-void chat_viewer_quit(gint viewer_num)
+void chat_spectator_quit(gint spectator_num)
 {
 	GtkTreeIter iter;
 	enum TFindResult found;
 
 	found =
 	    find_integer_in_tree(GTK_TREE_MODEL(chat_completion_model),
-				 &iter, CHAT_PLAYER_NUM, viewer_num);
+				 &iter, CHAT_PLAYER_NUM, spectator_num);
 	if (found == FIND_MATCH_EXACT) {
 		gtk_list_store_remove(chat_completion_model, &iter);
 	}
@@ -291,8 +292,8 @@ void chat_parser(gint player_num, const gchar * chat)
 	}
 
 	if (color_chat_enabled) {
-		if (player_is_viewer(player_num))
-			tempchatcolor = MSG_VIEWER_CHAT;
+		if (player_is_spectator(player_num))
+			tempchatcolor = MSG_SPECTATOR_CHAT;
 		else
 			switch (player_num) {
 			case 0:
