@@ -13,7 +13,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gtk/gtktable.h>
+#include <gtk/gtk.h>
 
 #include "map.h"		/* For NO_RESOURCE */
 
