@@ -57,16 +57,27 @@ static GtkWidget *active_quote_label;
 static gboolean is_good_quote(const QuoteInfo * quote)
 {
 	gint idx;
+	gboolean interested;
+
 	g_assert(quote != NULL);
 	g_assert(quote->is_domestic);
+
+	interested = FALSE;
 	for (idx = 0; idx < NO_RESOURCE; idx++) {
 		gint we_supply = quote->var.d.receive[idx];
+		gint we_receive = quote->var.d.supply[idx];
 
+		/* Asked for too many, or we don't want to give it anymore */
 		if (we_supply > resource_asset(idx)
 		    || (we_supply > 0 && !we_supply_rows[idx].enabled))
 			return FALSE;
+
+		/* We want one of the offered resources */
+		if (we_receive > 0 && we_receive_rows[idx].enabled) {
+			interested = TRUE;
+		}
 	}
-	return TRUE;
+	return interested;
 }
 
 /** @return TRUE if at least one resource is asked/offered */
@@ -508,17 +519,17 @@ GtkWidget *trade_build_page(void)
 	gtk_widget_show(vbox);
 	gtk_box_pack_start(GTK_BOX(panel_mainbox), vbox, FALSE, TRUE, 0);
 
-	we_receive_frame =
-	    /* Frame title, trade: I want to trade these resources */
-	    build_trade_resources_frame(_("I want"), we_receive_rows);
-	gtk_box_pack_start(GTK_BOX(vbox), we_receive_frame,
+	gtk_box_pack_start(GTK_BOX(vbox),
+			   /* Frame title, trade: I want to trade these resources */
+			   build_trade_resources_frame(_("I want"),
+						       we_receive_rows),
 			   FALSE, TRUE, 0);
 
-	gtk_box_pack_start(GTK_BOX(vbox),
-			   /* Frame title, trade: I want these resources in return */
-			   build_trade_resources_frame(_("Give them"),
-						       we_supply_rows),
-			   FALSE, TRUE, 0);
+	we_receive_frame =
+	    /* Frame title, trade: I want these resources in return */
+	    build_trade_resources_frame(_("Give them"), we_supply_rows);
+	gtk_box_pack_start(GTK_BOX(vbox), we_receive_frame, FALSE, TRUE,
+			   0);
 
 	bbox = gtk_hbutton_box_new();
 	gtk_widget_show(bbox);
