@@ -30,53 +30,60 @@
 
 #include "game.h"
 #include "cards.h"
+#include "log.h"
 
 const gchar *default_player_style = "square";
 
 typedef enum {
-	PARAM_STRING,
+	PARAM_SINGLE_LINE,
+	PARAM_MULTIPLE_LINES,
 	PARAM_INT,
 	PARAM_BOOL,
-	PARAM_INTLIST
+	PARAM_INTLIST,
+	PARAM_OBSOLETE_DATA
 } ParamType;
 
 typedef struct {
-	const gchar *name;
-	ParamType type;
-	int offset;
+	const gchar *name; /**< Text version of the parameter */
+	ClientVersionType first_version; /**< First version with this parameter */
+	ParamType type;	/**< Data type */
+	int offset; /**< Offset in the struct */
 } Param;
 
-#define PARAM_V(name, type, var) #name, type, G_STRUCT_OFFSET(GameParams, var)
-#define PARAM(var, type) PARAM_V(var, type, var)
+#define PARAM(name, first, type, var) #name, first, type, G_STRUCT_OFFSET(GameParams, var)
+#define PARAM_OBSOLETE(var) #var, UNKNOWN_VERSION, PARAM_OBSOLETE_DATA, -1
 
 /* *INDENT-OFF* */
 static Param game_params[] = {
-	{PARAM(title, PARAM_STRING)},
-	{PARAM_V(random-terrain, PARAM_BOOL, random_terrain)},
-	{PARAM_V(strict-trade, PARAM_BOOL, strict_trade)},
-	{PARAM_V(domestic-trade, PARAM_BOOL, domestic_trade)},
-	{PARAM_V(num-players, PARAM_INT, num_players)},
-	{PARAM_V(sevens-rule, PARAM_INT, sevens_rule)},
-	{PARAM_V(victory-points, PARAM_INT, victory_points)},
-	{PARAM_V(check-victory-at-end-of-turn, PARAM_BOOL, check_victory_at_end_of_turn)},
-	{PARAM_V(num-roads, PARAM_INT, num_build_type[BUILD_ROAD])},
-	{PARAM_V(num-bridges, PARAM_INT, num_build_type[BUILD_BRIDGE])},
-	{PARAM_V(num-ships, PARAM_INT, num_build_type[BUILD_SHIP])},
-	{PARAM_V(num-settlements, PARAM_INT, num_build_type[BUILD_SETTLEMENT])},
-	{PARAM_V(num-cities, PARAM_INT, num_build_type[BUILD_CITY])},
-	{PARAM_V(num-city-walls, PARAM_INT, num_build_type[BUILD_CITY_WALL])},
-	{PARAM_V(resource-count, PARAM_INT, resource_count)},
-	{PARAM_V(develop-road, PARAM_INT, num_develop_type[DEVEL_ROAD_BUILDING])},
-	{PARAM_V(develop-monopoly, PARAM_INT, num_develop_type[DEVEL_MONOPOLY])},
-	{PARAM_V(develop-plenty, PARAM_INT, num_develop_type[DEVEL_YEAR_OF_PLENTY])},
-	{PARAM_V(develop-chapel, PARAM_INT, num_develop_type[DEVEL_CHAPEL])},
-	{PARAM_V(develop-university, PARAM_INT, num_develop_type[DEVEL_UNIVERSITY])},
-	{PARAM_V(develop-governor, PARAM_INT, num_develop_type[DEVEL_GOVERNORS_HOUSE])},
-	{PARAM_V(develop-library, PARAM_INT, num_develop_type[DEVEL_LIBRARY])},
-	{PARAM_V(develop-market, PARAM_INT, num_develop_type[DEVEL_MARKET])},
-	{PARAM_V(develop-soldier, PARAM_INT, num_develop_type[DEVEL_SOLDIER])},
-	{PARAM_V(use-pirate, PARAM_BOOL, use_pirate)},
-	{PARAM_V(island-discovery-bonus, PARAM_INTLIST, island_discovery_bonus)}
+	{PARAM(title, FIRST_VERSION, PARAM_SINGLE_LINE, title)},
+	{PARAM_OBSOLETE(variant)},
+	{PARAM(random-terrain, FIRST_VERSION, PARAM_BOOL, random_terrain)},
+	{PARAM(strict-trade, FIRST_VERSION, PARAM_BOOL, strict_trade)},
+	{PARAM(domestic-trade, FIRST_VERSION, PARAM_BOOL, domestic_trade)},
+	{PARAM(num-players, FIRST_VERSION, PARAM_INT, num_players)},
+	{PARAM(sevens-rule, FIRST_VERSION, PARAM_INT, sevens_rule)},
+	{PARAM(victory-points, FIRST_VERSION, PARAM_INT, victory_points)},
+	{PARAM(check-victory-at-end-of-turn, FIRST_VERSION, PARAM_BOOL, check_victory_at_end_of_turn)},
+	{PARAM(num-roads, FIRST_VERSION, PARAM_INT, num_build_type[BUILD_ROAD])},
+	{PARAM(num-bridges, FIRST_VERSION, PARAM_INT, num_build_type[BUILD_BRIDGE])},
+	{PARAM(num-ships, FIRST_VERSION, PARAM_INT, num_build_type[BUILD_SHIP])},
+	{PARAM(num-settlements, FIRST_VERSION, PARAM_INT, num_build_type[BUILD_SETTLEMENT])},
+	{PARAM(num-cities, FIRST_VERSION, PARAM_INT, num_build_type[BUILD_CITY])},
+	{PARAM(num-city-walls, V0_11, PARAM_INT, num_build_type[BUILD_CITY_WALL])},
+	{PARAM(resource-count, FIRST_VERSION, PARAM_INT, resource_count)},
+	{PARAM(develop-road, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_ROAD_BUILDING])},
+	{PARAM(develop-monopoly, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_MONOPOLY])},
+	{PARAM(develop-plenty, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_YEAR_OF_PLENTY])},
+	{PARAM(develop-chapel, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_CHAPEL])},
+	{PARAM(develop-university, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_UNIVERSITY])},
+	{PARAM(develop-governor, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_GOVERNORS_HOUSE])},
+	{PARAM(develop-library, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_LIBRARY])},
+	{PARAM(develop-market, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_MARKET])},
+	{PARAM(develop-soldier, FIRST_VERSION, PARAM_INT, num_develop_type[DEVEL_SOLDIER])},
+	{PARAM(use-pirate, FIRST_VERSION, PARAM_BOOL, use_pirate)},
+	{PARAM(island-discovery-bonus, FIRST_VERSION, PARAM_INTLIST, island_discovery_bonus)},
+	{PARAM(#, FIRST_VERSION, PARAM_MULTIPLE_LINES, comments)},
+	{PARAM(desc, V14, PARAM_MULTIPLE_LINES, description)},
 };
 /* *INDENT-ON* */
 
@@ -92,11 +99,36 @@ void params_free(GameParams * params)
 {
 	if (params == NULL)
 		return;
+	gint idx;
+	gchar *str;
+	GArray *int_list;
 
-	if (params->title != NULL)
-		g_free(params->title);
-	if (params->map != NULL)
-		map_free(params->map);
+	for (idx = 0; idx < G_N_ELEMENTS(game_params); idx++) {
+		Param *param = game_params + idx;
+
+		switch (param->type) {
+		case PARAM_SINGLE_LINE:
+		case PARAM_MULTIPLE_LINES:
+			str =
+			    G_STRUCT_MEMBER(gchar *, params,
+					    param->offset);
+			g_free(str);
+			break;
+		case PARAM_INT:
+		case PARAM_BOOL:
+			break;
+		case PARAM_INTLIST:
+			int_list = G_STRUCT_MEMBER(GArray *, params,
+						   param->offset);
+			if (int_list != NULL)
+				g_array_free(int_list, TRUE);
+			break;
+		case PARAM_OBSOLETE_DATA:
+			/* Obsolete rule: do nothing */
+			break;
+		}
+	}
+	map_free(params->map);
 	g_free(params);
 }
 
@@ -120,10 +152,7 @@ static gboolean match_word(gchar ** str, const gchar * word)
 	return FALSE;
 }
 
-/* Create a new array, filled with the list in str.
- * If the array has length zero, NULL is returned.
- */
-static GArray *build_int_list(const gchar * str)
+GArray *build_int_list(const gchar * str)
 {
 	GArray *array = g_array_new(FALSE, FALSE, sizeof(gint));
 	while (*str != '\0') {
@@ -157,32 +186,35 @@ static GArray *build_int_list(const gchar * str)
 	return array;
 }
 
-/* This function allocates a buffer and returns it.  It must be freed by the
- * caller.  */
-static gchar *format_int_list(const gchar * name, GArray * array)
+gchar *format_int_list(const gchar * name, GArray * array)
 {
-	gchar *old, *str = NULL;
+	gchar *old;
+	gchar *str;
 	int idx;
 
 	if (array == NULL)
 		return NULL;
 
 	if (array->len == 0) {
-		str = g_strdup(name);
-		return str;
+		return g_strdup(name);
 	}
+	if (name == NULL || strlen(name) == 0) {
+		str = g_strdup("");
+	} else {
+		str = g_strdup_printf("%s ", name);
+	};
 	for (idx = 0; idx < array->len; idx++) {
 		old = str;
 		if (idx == 0)
-			str = g_strdup_printf("%s %d", name,
-					      g_array_index(array, gint,
-							    idx));
+			str =
+			    g_strdup_printf("%s%d", str,
+					    g_array_index(array, gint,
+							  idx));
 		else
 			str = g_strdup_printf("%s,%d", str,
 					      g_array_index(array, gint,
 							    idx));
-		if (old)
-			g_free(old);
+		g_free(old);
 	}
 	return str;
 }
@@ -210,30 +242,69 @@ static gboolean find_no_setup(const Hex * hex, gpointer closure)
 	return FALSE;
 }
 
-void params_write_lines(GameParams * params, gboolean write_secrets,
-			WriteLineFunc func, gpointer user_data)
+void params_write_lines(GameParams * params, ClientVersionType version,
+			gboolean write_secrets, WriteLineFunc func,
+			gpointer user_data)
 {
 	gint idx;
 	gint y;
 	gchar *buff;
 	gchar *str;
 
-	switch (params->variant) {
-	case VAR_DEFAULT:
-		func(user_data, "variant default");
-		break;
-	case VAR_ISLANDS:
-		func(user_data, "variant islands");
-		break;
-	case VAR_INTIMATE:
-		func(user_data, "variant intimate");
-		break;
-	}
 	for (idx = 0; idx < G_N_ELEMENTS(game_params); idx++) {
 		Param *param = game_params + idx;
 
+		if (param->first_version > version) {
+			/* This rule is too new for the recipient */
+			/* Only notify the recipient when the rule is not in use */
+
+			switch (param->type) {
+			case PARAM_SINGLE_LINE:
+			case PARAM_MULTIPLE_LINES:
+				str =
+				    G_STRUCT_MEMBER(gchar *, params,
+						    param->offset);
+				if (!str || strlen(str) < 1) {
+					continue;
+				};
+				break;
+			case PARAM_INT:
+				if (G_STRUCT_MEMBER
+				    (gint, params, param->offset) < 1) {
+
+					continue;
+				};
+				break;
+			case PARAM_BOOL:
+				if (!G_STRUCT_MEMBER
+				    (gboolean, params, param->offset)) {
+					continue;
+				}
+				break;
+			case PARAM_INTLIST:
+				buff =
+				    format_int_list(param->name,
+						    G_STRUCT_MEMBER(GArray
+								    *,
+								    params,
+								    param->offset));
+				if (buff == NULL) {
+					continue;
+				};
+				g_free(buff);
+				break;
+			case PARAM_OBSOLETE_DATA:
+				/* Obsolete rule: go to the next rule */
+				continue;
+			}
+			buff = g_strdup_printf("new-rule %s", param->name);
+			func(user_data, buff);
+			g_free(buff);
+			continue;
+		}
+
 		switch (param->type) {
-		case PARAM_STRING:
+		case PARAM_SINGLE_LINE:
 			str =
 			    G_STRUCT_MEMBER(gchar *, params,
 					    param->offset);
@@ -243,6 +314,27 @@ void params_write_lines(GameParams * params, gboolean write_secrets,
 			func(user_data, buff);
 			g_free(buff);
 			break;
+		case PARAM_MULTIPLE_LINES:
+			str =
+			    G_STRUCT_MEMBER(gchar *, params,
+					    param->offset);
+			if (str) {
+				gchar **strv;
+				gchar **strv_it;
+				strv = g_strsplit(str, "\n", 0);
+				strv_it = strv;
+				while (*strv_it) {
+					buff =
+					    g_strdup_printf("%s %s",
+							    param->name,
+							    *strv_it);
+					func(user_data, buff);
+					g_free(buff);
+					strv_it++;
+				}
+				g_strfreev(strv);
+			}
+			break;
 		case PARAM_INT:
 			buff = g_strdup_printf("%s %d", param->name,
 					       G_STRUCT_MEMBER(gint,
@@ -271,6 +363,9 @@ void params_write_lines(GameParams * params, gboolean write_secrets,
 				g_free(buff);
 			}
 			break;
+		case PARAM_OBSOLETE_DATA:
+			/* Obsolete rule: do nothing */
+			break;
 		}
 	}
 	buff = format_int_list("chits", params->map->chits);
@@ -310,19 +405,8 @@ gboolean params_load_line(GameParams * params, gchar * line)
 		return TRUE;
 	}
 	line = skip_space(line);
-	if (*line == '#')
-		return TRUE;
 	if (*line == 0)
 		return TRUE;
-	if (match_word(&line, "variant")) {
-		if (match_word(&line, "islands"))
-			params->variant = VAR_ISLANDS;
-		else if (match_word(&line, "intimate"))
-			params->variant = VAR_INTIMATE;
-		else
-			params->variant = VAR_DEFAULT;
-		return TRUE;
-	}
 	if (match_word(&line, "map")) {
 		params->parsing_map = TRUE;
 		return TRUE;
@@ -362,7 +446,7 @@ gboolean params_load_line(GameParams * params, gchar * line)
 		if (!match_word(&line, param->name))
 			continue;
 		switch (param->type) {
-		case PARAM_STRING:
+		case PARAM_SINGLE_LINE:
 			str =
 			    G_STRUCT_MEMBER(gchar *, params,
 					    param->offset);
@@ -372,6 +456,23 @@ gboolean params_load_line(GameParams * params, gchar * line)
 			G_STRUCT_MEMBER(gchar *, params, param->offset) =
 			    str;
 			return TRUE;
+		case PARAM_MULTIPLE_LINES:
+			str =
+			    G_STRUCT_MEMBER(gchar *, params,
+					    param->offset);
+			if (str) {
+				gchar *copy;
+				copy =
+				    g_strconcat(str, "\n",
+						g_strchomp(line), NULL);
+				g_free(str);
+				str = copy;
+			} else {
+				str = g_strchomp(g_strdup(line));
+			}
+			G_STRUCT_MEMBER(gchar *, params, param->offset) =
+			    str;
+			return TRUE;
 		case PARAM_INT:
 			G_STRUCT_MEMBER(gint, params, param->offset) =
 			    atoi(line);
@@ -394,8 +495,19 @@ gboolean params_load_line(GameParams * params, gchar * line)
 			G_STRUCT_MEMBER(GArray *, params, param->offset) =
 			    array;
 			return array != NULL;
+		case PARAM_OBSOLETE_DATA:
+			log_message(MSG_ERROR, _("Obsolete rule: '%s'\n"),
+				    param->name);
+			return TRUE;
 		}
 	}
+	if (match_word(&line, "new-rule")) {
+		log_message(MSG_INFO,
+			    _("The game uses the new rule '%s', which "
+			      "is not yet supported. "
+			      "Consider upgrading.\n"), line);
+		return TRUE;
+	}
 	g_warning("Unknown keyword: %s", line);
 	return FALSE;
 }
@@ -473,13 +585,13 @@ GameParams *params_copy(const GameParams * params)
 	memcpy(&nonconst, params, sizeof(GameParams));
 	copy = params_new();
 	copy->map = map_copy(params->map);
-	copy->variant = params->variant;
 
 	for (idx = 0; idx < G_N_ELEMENTS(game_params); idx++) {
 		Param *param = game_params + idx;
 
 		switch (param->type) {
-		case PARAM_STRING:
+		case PARAM_SINGLE_LINE:
+		case PARAM_MULTIPLE_LINES:
 			G_STRUCT_MEMBER(gchar *, copy, param->offset)
 			    =
 			    g_strdup(G_STRUCT_MEMBER
@@ -509,6 +621,9 @@ GameParams *params_copy(const GameParams * params)
 				g_free(buff);
 			}
 			break;
+		case PARAM_OBSOLETE_DATA:
+			/* Obsolete rule: do nothing */
+			break;
 		}
 	}
 
@@ -517,6 +632,139 @@ GameParams *params_copy(const GameParams * params)
 	return copy;
 }
 
+static void append_to_string(gpointer base, const gchar * additional_text)
+{
+	gchar **b = base;
+	gchar *old = *b;
+	if (*b == NULL) {
+		*b = g_strdup(additional_text);
+	} else {
+		*b = g_strdup_printf("%s\n%s", old, additional_text);
+	}
+	g_free(old);
+}
+
+gboolean params_is_equal(const GameParams * params1,
+			 const GameParams * params2)
+{
+	gint idx;
+	gchar *buff1;
+	gchar *buff2;
+	gboolean is_different;
+
+	/* Compare the map */
+	if (params1->map->y_size != params2->map->y_size) {
+		return FALSE;
+	};
+	for (idx = 0; idx < params1->map->y_size; idx++) {
+		buff1 = map_format_line(params1->map, TRUE, idx);
+		buff2 = map_format_line(params2->map, TRUE, idx);
+
+		is_different = g_strcmp0(buff1, buff2) != 0;
+		g_free(buff1);
+		g_free(buff2);
+		if (is_different) {
+			return FALSE;
+		}
+	}
+
+	buff1 = format_int_list("", params1->map->chits);
+	buff2 = format_int_list("", params2->map->chits);
+	is_different = g_strcmp0(buff1, buff2) != 0;
+	g_free(buff1);
+	g_free(buff2);
+	if (is_different) {
+		return FALSE;
+	}
+
+	struct nosetup_t tmp;
+	buff1 = NULL;
+	tmp.user_data = &buff1;
+	tmp.func = append_to_string;
+	map_traverse_const(params1->map, find_no_setup, &tmp);
+	buff2 = NULL;
+	tmp.user_data = &buff2;
+	map_traverse_const(params2->map, find_no_setup, &tmp);
+
+	is_different = g_strcmp0(buff1, buff2) != 0;
+	g_free(buff1);
+	g_free(buff2);
+	if (is_different) {
+		return FALSE;
+	}
+
+	/* Compare the game parameters */
+
+	/* Copy the const parameter to a non-const version, because
+	 * G_STRUCT_MEMBER doesn't want const values.  Note that this
+	 * variable does not own its pointers, that is, they don't have to
+	 * be freed when it goes out of scope. */
+	GameParams nonconst1;
+	GameParams nonconst2;
+	memcpy(&nonconst1, params1, sizeof(GameParams));
+	memcpy(&nonconst2, params2, sizeof(GameParams));
+
+	for (idx = 0; idx < G_N_ELEMENTS(game_params); idx++) {
+		const Param *param = game_params + idx;
+
+		switch (param->type) {
+		case PARAM_SINGLE_LINE:
+		case PARAM_MULTIPLE_LINES:
+			if (g_strcmp0
+			    (G_STRUCT_MEMBER
+			     (gchar *, &nonconst1, param->offset),
+			     G_STRUCT_MEMBER(gchar *, &nonconst2,
+					     param->offset)) != 0) {
+				return FALSE;
+			}
+			break;
+		case PARAM_INT:
+			if (G_STRUCT_MEMBER
+			    (gint, &nonconst1,
+			     param->offset) != G_STRUCT_MEMBER(gint,
+							       &nonconst2,
+							       param->offset))
+			{
+				return FALSE;
+			}
+			break;
+		case PARAM_BOOL:
+			if (G_STRUCT_MEMBER
+			    (gboolean, &nonconst1,
+			     param->offset) != G_STRUCT_MEMBER(gboolean,
+							       &nonconst2,
+							       param->offset))
+			{
+				return FALSE;
+			}
+			break;
+		case PARAM_INTLIST:
+			buff1 = format_int_list("",
+						G_STRUCT_MEMBER(GArray *,
+								&nonconst1,
+								param->
+								offset));
+			buff2 =
+			    format_int_list("",
+					    G_STRUCT_MEMBER(GArray *,
+							    &nonconst2,
+							    param->offset));
+
+			is_different = g_strcmp0(buff1, buff2) != 0;
+			g_free(buff1);
+			g_free(buff2);
+			if (is_different) {
+				return FALSE;
+			}
+			break;
+		case PARAM_OBSOLETE_DATA:
+			/* Obsolete rule: do nothing */
+			break;
+		}
+	}
+	return TRUE;
+}
+
 /** Returns TRUE if the params are valid */
 gboolean params_load_finish(GameParams * params)
 {
@@ -560,13 +808,49 @@ gboolean params_write_file(GameParams * params, const gchar * fname)
 		g_warning("could not open '%s'", fname);
 		return FALSE;
 	}
-	params_write_lines(params, TRUE, write_one_line, fp);
+	params_write_lines(params, LATEST_VERSION, TRUE, write_one_line,
+			   fp);
 
 	fclose(fp);
 
 	return TRUE;
 }
 
+ClientVersionType client_version_type_from_string(const gchar * cvt)
+{
+	if (!strcmp(cvt, "0.10")) {
+		return V0_10;
+	} else if (!strcmp(cvt, "0.11")) {
+		return V0_11;
+	} else if (!strcmp(cvt, "0.12")) {
+		return V0_12;
+	} else if (!strcmp(cvt, "14")) {
+		return V14;
+	} else {
+		return UNKNOWN_VERSION;
+	}
+}
+
+gboolean can_client_connect_to_server(ClientVersionType client_version,
+				      ClientVersionType server_version)
+{
+	if (client_version == UNKNOWN_VERSION) {
+		return FALSE;
+	} else if (server_version == UNKNOWN_VERSION) {
+		return FALSE;
+	} else if (client_version > server_version) {
+		/* By design the server must be the newest */
+		return FALSE;
+	} else if (client_version == server_version) {
+		return TRUE;
+	} else {
+		/* In compatibility mode */
+		/* If somehow the backwards compatibility needs to be broken,
+		   this function should return FALSE here */
+		return TRUE;
+	}
+}
+
 WinnableState params_check_winnable_state(const GameParams * params,
 					  gchar ** win_message,
 					  gchar ** point_specification)
