@@ -2,7 +2,7 @@
  *   Go buy a copy.
  *
  * Copyright (C) 1999 Dave Cole
- * Copyright (C) 2005 Roland Clobus <rclobus@bigfoot.com>
+ * Copyright (C) 2005-2010 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,30 +21,6 @@
 
 #include "gtkbugs.h"
 
-void set_pixbuf_tree_view_column_autogrow(GtkWidget * parent_widget,
-					  GtkTreeViewColumn * column)
-{
-	if (gtk_major_version == 2
-	    && (gtk_minor_version >= 5 && gtk_minor_version <= 6)) {
-		gint horizontal_separator, focus_line_width, icon_width;
-
-		gtk_tree_view_column_set_sizing(column,
-						GTK_TREE_VIEW_COLUMN_FIXED);
-		gtk_widget_style_get(parent_widget,
-				     "horizontal_separator",
-				     &horizontal_separator,
-				     "focus-line-width", &focus_line_width,
-				     NULL);
-		gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &icon_width,
-				     NULL);
-		gtk_tree_view_column_set_fixed_width(column,
-						     icon_width +
-						     2 *
-						     horizontal_separator +
-						     focus_line_width);
-	}
-}
-
 /** Since Gtk+ 2.6 you cannot press a button twice, without moving the
  *  mouse.
  */
@@ -59,17 +35,30 @@ void action_set_sensitive(GtkAction * action, gboolean sensitive)
 	gtk_action_set_sensitive(action, sensitive);
 }
 
+/* Since 2.20 GTK_WIDGET_STATE and gtk_button_enter are deprecated.
+ * The bug below is fixed in 2.18.2
+ *
+ * When the code is built on >=2.20 and run <2.20 you might be hit by the
+ * bug, but in that case you'll be running a newer version of Pioneers with
+ * older libraries, which should not happen with many package managers.
+ * It doesn't hurt to apply this workaround for >=2.18.2
+ */
 void widget_set_sensitive(GtkWidget * widget, gboolean sensitive)
 {
+#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 20)
 	GtkWidget *button;
+#endif
 
 	gtk_widget_set_sensitive(widget, sensitive);
 
+#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 20)
 	/** @bug Gtk bug 56070. If the mouse is over a toolbar button that
 	 *  becomes sensitive, one can't click it without moving the mouse out
 	 *  and in again. This bug is registered in Bugzilla as a Gtk bug. The
 	 *  workaround tests if the mouse is inside the currently sensitivized
 	 *  button, and if yes call button_enter()
+	 *
+         *  Fixed in Gtk 2.18.2
 	 */
 	if (!GTK_IS_BIN(widget))
 		return;
@@ -88,8 +77,5 @@ void widget_set_sensitive(GtkWidget * widget, gboolean sensitive)
 			gtk_widget_set_state(widget, GTK_STATE_PRELIGHT);
 		}
 	}
-}
-
-#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12)
-GtkTooltips *tooltips = NULL;
 #endif
+}
