@@ -24,13 +24,6 @@
 
 #include <gtk/gtk.h>
 
-/** @bug 2005-07-25 In Gtk+ 2.6 the pixbuf column is 
- *  one pixel too small, the focus_line_width is not used correctly.
- *  See also http://bugzilla.gnome.org/show_bug.cgi?id=147867
- */
-void set_pixbuf_tree_view_column_autogrow(GtkWidget * parent_widget,
-					  GtkTreeViewColumn * column);
-
 /** @bug 2006-01-15 In Gtk+ 2.4 it is not possible to disable actions.
  *  This will be close to its functionality, but will show -/- in the 
  *  menus for the shortcut keys.
@@ -42,16 +35,4 @@ void action_set_sensitive(GtkAction * action, gboolean sensitive);
  */
 void widget_set_sensitive(GtkWidget * widget, gboolean sensitive);
 
-/* Not a Gtk+ bug, but a work around is presented here.
- * In Gtk+ 2.12 GtkToolTips has been replaced by GtkToolTip.
- */
-#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12)
-#include <gtk/gtktooltips.h>
-extern GtkTooltips *tooltips;
-#define gtk_widget_set_tooltip_text(widget, text) \
-	if (tooltips == NULL) \
-		tooltips = gtk_tooltips_new(); \
-	gtk_tooltips_set_tip(tooltips, widget, text, NULL)
-#endif
-
 #endif
