@@ -42,6 +42,12 @@ typedef enum {
 	ROBBER_CURSOR
 } CursorType;
 
+typedef enum {
+	MAP_EDGE,
+	MAP_NODE,
+	MAP_HEX
+} MapElementType;
+
 typedef union {
 	const Hex *hex;
 	const Node *node;
@@ -59,10 +65,7 @@ typedef struct _Mode Mode;
 typedef struct {
 	GtkWidget *area;	   /**< render map in this drawing area */
 	GdkPixmap *pixmap;	   /**< off screen pixmap for drawing */
-	GdkGC *gc;		   /**< gc for map drawing */
-	GdkRegion *hex_region;	   /**< region for filling hex */
-	GdkRegion *node_region[6]; /**< region for filling node */
-	GdkRegion *edge_region[6]; /**< regions for locating edges */
+	cairo_t *cr;		   /**< cairo for map drawing */
 	PangoLayout *layout;	   /**< layout object for rendering text */
 	gint initial_font_size;	   /**< initial font size */
 
@@ -84,6 +87,7 @@ typedef struct {
 	gint x_point;		   /**< x offset of node 0 from centre */
 	gint y_point;		   /**< y offset of node 0 from centre */
 
+	gboolean is_custom_view;   /**< false if all hexes are shown and centered */
 	gint x_margin;		   /**< margin to leave empty */
 	gint y_margin;		   /**< margin to leave empty */
 	gint width;		   /**< pixel width of map */
@@ -96,7 +100,6 @@ void guimap_delete(GuiMap * gmap);
 void guimap_reset(GuiMap * gmap);
 GtkWidget *guimap_build_drawingarea(GuiMap * gmap, gint width,
 				    gint height);
-GdkPixmap *guimap_terrain(Terrain terrain);
 
 void guimap_road_polygon(const GuiMap * gmap, const Edge * edge,
 			 Polygon * poly);
@@ -112,21 +115,29 @@ void guimap_city_wall_polygon(const GuiMap * gmap, const Node * node,
 			      Polygon * poly);
 
 gint guimap_get_chit_radius(PangoLayout * layout, gboolean show_dots);
-void draw_dice_roll(PangoLayout * layout, GdkPixmap * pixmap, GdkGC * gc,
-		    gint x_offset, gint y_offset, gint radius,
-		    gint n, gint terrain, gboolean highlight);
+void draw_dice_roll(PangoLayout * layout, cairo_t * cr, gdouble x_offset,
+		    gdouble y_offset, gdouble radius, gint n, gint terrain,
+		    gboolean highlight);
 
 void guimap_scale_with_radius(GuiMap * gmap, gint radius);
 void guimap_scale_to_size(GuiMap * gmap, gint width, gint height);
 void guimap_display(GuiMap * gmap);
+void guimap_zoom_normal(GuiMap * gmap);
+void guimap_zoom_center_map(GuiMap * gmap);
 
 void guimap_highlight_chits(GuiMap * gmap, gint roll);
 void guimap_draw_edge(GuiMap * gmap, const Edge * edge);
 void guimap_draw_node(GuiMap * gmap, const Node * node);
 void guimap_draw_hex(GuiMap * gmap, const Hex * hex);
 
+Node *guimap_find_node(GuiMap * gmap, gint x, gint y);
 Hex *guimap_find_hex(GuiMap * gmap, gint x, gint y);
 
+gint guimap_distance_cursor(const GuiMap * gmap,
+			    const MapElement * element,
+			    MapElementType type, gint cursor_x,
+			    gint cursor_y);
+
 void guimap_cursor_set(GuiMap * gmap, CursorType cursor_type, gint owner,
 		       CheckFunc check_func, SelectFunc select_func,
 		       CancelFunc cancel_func,
