@@ -13,6 +13,7 @@
 #include <string.h>
 #include "guimap.h"
 #include "gtkbugs.h"
+#include "gtkcompat.h"
 
 #include "select-game.h"
 
@@ -144,7 +145,7 @@ void select_game_add(SelectGame * sg, const gchar * game_title)
  * The default game will be the active item.
  */
 void select_game_add_with_map(SelectGame * sg, const gchar * game_title,
-			      Map * map)
+			      const Map * map)
 {
 	GtkTreeIter iter;
 	gchar *title = g_strdup(game_title);
@@ -159,13 +160,14 @@ void select_game_add_with_map(SelectGame * sg, const gchar * game_title,
 
 	gmap = guimap_new();
 	gmap->pixmap =
-	    gdk_pixmap_new(sg->combo_box->window, width, height,
-			   gdk_visual_get_system()->depth);
+	    gdk_pixmap_new(gtk_widget_get_window(sg->combo_box), width,
+			   height,
+			   gdk_visual_get_depth(gdk_visual_get_system()));
 	gmap->width = width;
 	gmap->height = height;
 	gmap->area = sg->combo_box;
 	g_object_ref(gmap->area);
-	gmap->map = map;
+	gmap->map = map_copy(map);
 	guimap_scale_to_size(gmap, width, height);
 	guimap_display(gmap);
 
