@@ -43,7 +43,7 @@ GtkWidget *select_game_new(void);
 void select_game_set_default(SelectGame * sg, const gchar * game_title);
 void select_game_add(SelectGame * sg, const gchar * game_title);
 void select_game_add_with_map(SelectGame * sg, const gchar * game_title,
-			      Map * map);
+			      const Map * map);
 const gchar *select_game_get_active(SelectGame * sg);
 
 G_END_DECLS
