@@ -100,11 +100,74 @@ static TColor default_colors[] = {
 	TCOL_INIT(0xff00, 0xda00, 0xb900)
 };
 
+#define offs(elem)           ((size_t)(&(((MapTheme *)0)->elem)))
+#define telem(type,theme,tv) (*((type *)((char *)theme + tv->offset)))
+
+typedef enum { FNAME, STR, COL, SCMODE } vartype;
+
+static struct tvars {
+	const char *name;
+	gboolean optional;
+	vartype type;
+	int override;
+	size_t offset;
+} theme_vars[] = {
+	{
+	"name", TRUE, STR, -1, offs(name)}, {
+	"hill-tile", FALSE, FNAME, HILL_TILE,
+		    offs(terrain_tile_names[HILL_TILE])}, {
+	"field-tile", FALSE, FNAME, FIELD_TILE,
+		    offs(terrain_tile_names[FIELD_TILE])}, {
+	"mountain-tile", FALSE, FNAME, MOUNTAIN_TILE,
+		    offs(terrain_tile_names[MOUNTAIN_TILE])}, {
+	"pasture-tile", FALSE, FNAME, PASTURE_TILE,
+		    offs(terrain_tile_names[PASTURE_TILE])}, {
+	"forest-tile", FALSE, FNAME, FOREST_TILE,
+		    offs(terrain_tile_names[FOREST_TILE])}, {
+	"desert-tile", FALSE, FNAME, -1,
+		    offs(terrain_tile_names[DESERT_TILE])}, {
+	"sea-tile", FALSE, FNAME, -1, offs(terrain_tile_names[SEA_TILE])},
+	{
+	"gold-tile", FALSE, FNAME, GOLD_TILE,
+		    offs(terrain_tile_names[GOLD_TILE])}, {
+	"board-tile", FALSE, FNAME, -1,
+		    offs(terrain_tile_names[BOARD_TILE])}, {
+	"brick-port-tile", TRUE, FNAME, -1,
+		    offs(port_tile_names[HILL_PORT_TILE])}, {
+	"grain-port-tile", TRUE, FNAME, -1,
+		    offs(port_tile_names[FIELD_PORT_TILE])}, {
+	"ore-port-tile", TRUE, FNAME, -1,
+		    offs(port_tile_names[MOUNTAIN_PORT_TILE])}, {
+	"wool-port-tile", TRUE, FNAME, -1,
+		    offs(port_tile_names[PASTURE_PORT_TILE])}, {
+	"lumber-port-tile", TRUE, FNAME, -1,
+		    offs(port_tile_names[FOREST_PORT_TILE])}, {
+	"nores-port-tile", TRUE, FNAME, -1,
+		    offs(port_tile_names[ANY_PORT_TILE])}, {
+	"chip-bg-color", TRUE, COL, -1, offs(colors[TC_CHIP_BG])}, {
+	"chip-fg-color", TRUE, COL, -1, offs(colors[TC_CHIP_FG])}, {
+	"chip-bd-color", TRUE, COL, -1, offs(colors[TC_CHIP_BD])}, {
+	"chip-hi-bg-color", TRUE, COL, -1, offs(colors[TC_CHIP_H_BG])},
+	{
+	"chip-hi-fg-color", TRUE, COL, -1, offs(colors[TC_CHIP_H_FG])},
+	{
+	"port-bg-color", TRUE, COL, -1, offs(colors[TC_PORT_BG])}, {
+	"port-fg-color", TRUE, COL, -1, offs(colors[TC_PORT_FG])}, {
+	"port-bd-color", TRUE, COL, -1, offs(colors[TC_PORT_BD])}, {
+	"robber-fg-color", TRUE, COL, -1, offs(colors[TC_ROBBER_FG])},
+	{
+	"robber-bd-color", TRUE, COL, -1, offs(colors[TC_ROBBER_BD])},
+	{
+	"hex-bd-color", TRUE, COL, -1, offs(colors[TC_HEX_BD])}, {
+	"scaling", FALSE, SCMODE, -1, offs(scaling)}
+};
+
 static GList *theme_list = NULL;
 static MapTheme *current_theme = NULL;
 static GList *callback_list = NULL;
 
 static gboolean theme_initialize(MapTheme * t);
+static void theme_cleanup(MapTheme * t);
 static void theme_scan_dir(const gchar * themes_path);
 static gint getvar(gchar ** p, const gchar * filename, gint lno);
 static char *getval(char **p, const gchar * filename, int lno);
@@ -172,6 +235,17 @@ void themes_init(void)
 	current_theme = t;
 }
 
+void themes_cleanup(void)
+{
+	GList *list = theme_list;
+	while (list) {
+		theme_cleanup(list->data);
+		list = g_list_next(list);
+	}
+	g_list_free(theme_list);
+	g_list_free(callback_list);
+}
+
 void theme_scan_dir(const gchar * themes_path)
 {
 	GDir *dir;
@@ -302,9 +376,6 @@ static gboolean theme_initialize(MapTheme * t)
 		t->scaledata[i].aspect = 1.0 *
 		    gdk_pixbuf_get_width(pixbuf) /
 		    gdk_pixbuf_get_height(pixbuf);
-		gdk_pixbuf_render_pixmap_and_mask(pixbuf,
-						  &(t->terrain_tiles[i]),
-						  NULL, 1);
 	}
 
 	/* load port tiles */
@@ -355,6 +426,36 @@ static gboolean theme_initialize(MapTheme * t)
 	return TRUE;
 }
 
+static void theme_cleanup(MapTheme * t)
+{
+	int i;
+
+	/* terrain tiles */
+	for (i = 0; i < G_N_ELEMENTS(t->terrain_tiles); ++i) {
+		g_object_unref(t->terrain_tiles[i]);
+		g_object_unref(t->scaledata[i].image);
+		g_object_unref(t->scaledata[i].native_image);
+	}
+	/* port tiles */
+	for (i = 0; i < G_N_ELEMENTS(t->port_tiles); ++i) {
+		if (t->port_tiles[i] != NULL) {
+			g_object_unref(t->port_tiles[i]);
+		}
+	}
+	for (i = 0; i < G_N_ELEMENTS(theme_vars); i++) {
+		switch (theme_vars[i].type) {
+		case STR:
+		case FNAME:
+			g_free(telem(char *, t, (&theme_vars[i])));
+			break;
+		default:
+			/* No action required */
+			break;
+		}
+	}
+	g_free(t);
+}
+
 void theme_rescale(int new_width)
 {
 	int i;
@@ -383,6 +484,12 @@ void theme_rescale(int new_width)
 	if (new_width <= 0)
 		new_width = 1;
 
+	/* no need to scale again */
+	if (new_width == current_theme->current_width) {
+		return;
+	}
+	current_theme->current_width = new_width;
+
 	for (i = 0; i < G_N_ELEMENTS(current_theme->terrain_tiles); ++i) {
 		int new_height;
 		if (i == BOARD_TILE)
@@ -393,7 +500,7 @@ void theme_rescale(int new_width)
 		if (new_height <= 0)
 			new_height = 1;
 		/* rescale the pixbuf */
-		gdk_pixbuf_unref(current_theme->scaledata[i].image);
+		g_object_unref(current_theme->scaledata[i].image);
 		current_theme->scaledata[i].image =
 		    gdk_pixbuf_scale_simple(current_theme->scaledata[i].
 					    native_image, new_width,
@@ -411,68 +518,6 @@ void theme_rescale(int new_width)
 	}
 }
 
-#define offs(elem)           ((size_t)(&(((MapTheme *)0)->elem)))
-#define telem(type,theme,tv) (*((type *)((char *)theme + tv->offset)))
-
-typedef enum { FNAME, STR, COL, SCMODE } vartype;
-
-static struct tvars {
-	const char *name;
-	gboolean optional;
-	vartype type;
-	int override;
-	size_t offset;
-} theme_vars[] = {
-	{
-	"name", TRUE, STR, -1, offs(name)}, {
-	"hill-tile", FALSE, FNAME, HILL_TILE,
-		    offs(terrain_tile_names[HILL_TILE])}, {
-	"field-tile", FALSE, FNAME, FIELD_TILE,
-		    offs(terrain_tile_names[FIELD_TILE])}, {
-	"mountain-tile", FALSE, FNAME, MOUNTAIN_TILE,
-		    offs(terrain_tile_names[MOUNTAIN_TILE])}, {
-	"pasture-tile", FALSE, FNAME, PASTURE_TILE,
-		    offs(terrain_tile_names[PASTURE_TILE])}, {
-	"forest-tile", FALSE, FNAME, FOREST_TILE,
-		    offs(terrain_tile_names[FOREST_TILE])}, {
-	"desert-tile", FALSE, FNAME, -1,
-		    offs(terrain_tile_names[DESERT_TILE])}, {
-	"sea-tile", FALSE, FNAME, -1, offs(terrain_tile_names[SEA_TILE])},
-	{
-	"gold-tile", FALSE, FNAME, GOLD_TILE,
-		    offs(terrain_tile_names[GOLD_TILE])}, {
-	"board-tile", FALSE, FNAME, -1,
-		    offs(terrain_tile_names[BOARD_TILE])}, {
-	"brick-port-tile", TRUE, FNAME, -1,
-		    offs(port_tile_names[HILL_PORT_TILE])}, {
-	"grain-port-tile", TRUE, FNAME, -1,
-		    offs(port_tile_names[FIELD_PORT_TILE])}, {
-	"ore-port-tile", TRUE, FNAME, -1,
-		    offs(port_tile_names[MOUNTAIN_PORT_TILE])}, {
-	"wool-port-tile", TRUE, FNAME, -1,
-		    offs(port_tile_names[PASTURE_PORT_TILE])}, {
-	"lumber-port-tile", TRUE, FNAME, -1,
-		    offs(port_tile_names[FOREST_PORT_TILE])}, {
-	"nores-port-tile", TRUE, FNAME, -1,
-		    offs(port_tile_names[ANY_PORT_TILE])}, {
-	"chip-bg-color", TRUE, COL, -1, offs(colors[TC_CHIP_BG])}, {
-	"chip-fg-color", TRUE, COL, -1, offs(colors[TC_CHIP_FG])}, {
-	"chip-bd-color", TRUE, COL, -1, offs(colors[TC_CHIP_BD])}, {
-	"chip-hi-bg-color", TRUE, COL, -1, offs(colors[TC_CHIP_H_BG])},
-	{
-	"chip-hi-fg-color", TRUE, COL, -1, offs(colors[TC_CHIP_H_FG])},
-	{
-	"port-bg-color", TRUE, COL, -1, offs(colors[TC_PORT_BG])}, {
-	"port-fg-color", TRUE, COL, -1, offs(colors[TC_PORT_FG])}, {
-	"port-bd-color", TRUE, COL, -1, offs(colors[TC_PORT_BD])}, {
-	"robber-fg-color", TRUE, COL, -1, offs(colors[TC_ROBBER_FG])},
-	{
-	"robber-bd-color", TRUE, COL, -1, offs(colors[TC_ROBBER_BD])},
-	{
-	"hex-bd-color", TRUE, COL, -1, offs(colors[TC_HEX_BD])}, {
-	"scaling", FALSE, SCMODE, -1, offs(scaling)}
-};
-
 #define ERR1(formatstring, argument) \
 	g_warning("While reading %s at line %d:", filename, lno); \
 	g_warning(formatstring, argument);
@@ -596,7 +641,8 @@ static MapTheme *theme_config_parse(const gchar * themename,
 
 	t = g_malloc0(sizeof(MapTheme));
 	/* Initially the theme name is equal to the directory name */
-	t->name = g_filename_to_utf8(themename, -1, NULL, NULL, NULL);
+	t->name = g_strdup(themename);
+	t->current_width = -1;
 
 	used = g_malloc0(G_N_ELEMENTS(theme_vars) * sizeof(gboolean));
 
@@ -618,6 +664,9 @@ static MapTheme *theme_config_parse(const gchar * themename,
 
 		switch (tv->type) {
 		case STR:
+			if (telem(char *, t, tv)) {
+				g_free(telem(char *, t, tv));
+			}
 			telem(char *, t, tv) = g_strdup(q);
 			break;
 		case FNAME:
@@ -714,20 +763,22 @@ gint expose_terrain_cb(GtkWidget * area,
 	cairo_t *cr;
 	GdkPixbuf *p;
 	gint height;
+	GtkAllocation allocation;
 	Terrain terrain = GPOINTER_TO_INT(terraindata);
 
-	if (area->window == NULL)
+	if (gtk_widget_get_window(area) == NULL)
 		return FALSE;
 
-	cr = gdk_cairo_create(area->window);
+	cr = gdk_cairo_create(gtk_widget_get_window(area));
 
-	height = area->allocation.width / theme->scaledata[terrain].aspect;
+	gtk_widget_get_allocation(area, &allocation);
+	height = allocation.width / theme->scaledata[terrain].aspect;
 	p = gdk_pixbuf_scale_simple(theme->scaledata[terrain].native_image,
-				    area->allocation.width, height,
+				    allocation.width, height,
 				    GDK_INTERP_BILINEAR);
 
 	gdk_cairo_set_source_pixbuf(cr, p, 0, 0);
-	cairo_rectangle(cr, 0, 0, area->allocation.width, height);
+	cairo_rectangle(cr, 0, 0, allocation.width, height);
 	cairo_fill(cr);
 
 	g_object_unref(p);
