@@ -91,6 +91,7 @@ typedef enum {
 typedef struct _MapTheme {
 	gchar *name;
 	SCALEMODE scaling;
+	gint current_width;
 	const gchar *terrain_tile_names[TERRAIN_TILE_MAX];
 	const gchar *port_tile_names[PORT_TILE_MAX];
 	GdkPixmap *terrain_tiles[TERRAIN_TILE_MAX];
@@ -108,6 +109,7 @@ MapTheme *theme_get_current(void);
 GList *theme_get_list(void);
 void themes_init(void);
 void theme_register_callback(GCallback callback);
+void themes_cleanup(void);
 
 GdkPixmap *theme_get_terrain_pixmap(Terrain terrain);
 
