@@ -23,7 +23,6 @@
 #define __network_h
 
 #include <glib.h>
-#include <time.h>
 
 typedef enum {
 	NET_CONNECT,
@@ -36,30 +35,6 @@ typedef void (*NetNotifyFunc) (NetEvent event, void *user_data,
 			       gchar * line);
 
 typedef struct _Session Session;
-struct _Session {
-	int fd;
-	time_t last_response;	/* used for activity detection.  */
-	guint timer_id;
-	void *user_data;
-
-	gboolean connect_in_progress;
-	gboolean waiting_for_close;
-#ifdef HAVE_GETADDRINFO_ET_AL
-	struct addrinfo *base_ai;	/* Base addrinfo, to free later. */
-	struct addrinfo *current_ai;	/* Current connection method. */
-#endif
-	char *host;
-	char *port;
-
-	gint read_tag;
-	char read_buff[16 * 1024];
-	int read_len;
-	gboolean entered;
-	gint write_tag;
-	GList *write_queue;
-
-	NetNotifyFunc notify_func;
-};
 
 void set_enable_debug(gboolean enabled);
 void debug(const gchar * fmt, ...);
