@@ -36,6 +36,7 @@
 #include "game-devcards.h"
 #include "game-buildings.h"
 #include "game-resources.h"
+#include "scrollable-text-view.h"
 #include "guimap.h"
 #include "theme.h"
 #include "colors.h"
@@ -49,7 +50,6 @@
 
 static GtkWidget *toplevel;
 static gchar *default_game;
-static GameParams *params;
 static gchar *window_title;
 static gchar *open_filename;
 static GameSettings *game_settings;
@@ -57,6 +57,9 @@ static GameRules *game_rules;
 static GameDevCards *game_devcards;
 static GameBuildings *game_buildings;
 static GameResources *game_resources;
+static GtkWidget *game_title;
+static GtkWidget *game_description;
+static GtkWidget *game_comments;
 static GtkWidget *terrain_menu;
 static GtkWidget *roll_menu;
 static GtkWidget *roll_numbers[12 + 1];
@@ -181,12 +184,13 @@ static void fill_map(Map * map)
 
 static void canonicalize_map(Map * map)
 {
-	GArray *chits;
 	Hex *hex;
 	gint x, y;
 	gint sequence_number;
 
-	chits = g_array_new(FALSE, FALSE, sizeof(gint));
+	if (map->chits != NULL)
+		g_array_free(map->chits, TRUE);
+	map->chits = g_array_new(FALSE, FALSE, sizeof(gint));
 	sequence_number = 0;
 	for (y = 0; y < map->y_size; y++) {
 		for (x = 0; x < map->x_size; x++) {
@@ -194,16 +198,13 @@ static void canonicalize_map(Map * map)
 			if (hex == NULL)
 				continue;
 			if (hex->roll > 0) {
-				g_array_append_val(chits, hex->roll);
+				g_array_append_val(map->chits, hex->roll);
 				hex->chit_pos = sequence_number++;
 			} else if (hex->terrain == DESERT_TERRAIN) {
 				hex->chit_pos = sequence_number++;
 			}
 		}
 	}
-	if (map->chits != NULL)
-		g_array_free(map->chits, TRUE);
-	map->chits = chits;
 }
 
 static gboolean terrain_has_chit(Terrain terrain)
@@ -269,9 +270,10 @@ static void build_map_resize(GtkWidget * table, guint col, guint row,
 
 static void scale_map(GuiMap * gmap)
 {
-	guimap_scale_to_size(gmap,
-			     gmap->area->allocation.width,
-			     gmap->area->allocation.height);
+	GtkAllocation allocation;
+
+	gtk_widget_get_allocation(gmap->area, &allocation);
+	guimap_scale_to_size(gmap, allocation.width, allocation.height);
 	gtk_widget_queue_draw(gmap->area);
 }
 
@@ -285,12 +287,9 @@ static gint button_press_map_cb(GtkWidget * area, GdkEventButton * event,
 	gint num_ports;
 	gint i;
 
-	if (area->window == NULL || gmap->map == NULL)
+	if (gtk_widget_get_window(area) == NULL || gmap->map == NULL)
 		return FALSE;
 
-	if (event->button != 1)
-		return TRUE;
-
 	current_hex = guimap_find_hex(gmap, event->x, event->y);
 	if (current_hex == NULL)
 		return TRUE;
@@ -323,7 +322,7 @@ static gint button_press_map_cb(GtkWidget * area, GdkEventButton * event,
 		} else {
 			menu = terrain_menu;
 		}
-	} else if (current_hex->roll > 0) {
+	} else if (event->button == 3 && current_hex->roll > 0) {
 		menu = roll_menu;
 		for (i = 2; i <= 12; i++) {
 			if (roll_numbers[i] != NULL)
@@ -333,7 +332,8 @@ static gint button_press_map_cb(GtkWidget * area, GdkEventButton * event,
 		}
 		gtk_check_menu_item_set_active(shuffle_tile,
 					       current_hex->shuffle);
-	} else if (current_hex->terrain == SEA_TERRAIN) {
+	} else if (event->button == 3
+		   && current_hex->terrain == SEA_TERRAIN) {
 		num_ports = 0;
 		for (i = 0; i < 6; i++) {
 			adjacent = hex_in_direction(current_hex, i);
@@ -374,7 +374,7 @@ static gint key_press_map_cb(GtkWidget * area, GdkEventKey * event,
 	gint x, y;
 	gboolean plus10;
 
-	if (area->window == NULL || gmap->map == NULL)
+	if (gtk_widget_get_window(area) == NULL || gmap->map == NULL)
 		return FALSE;
 
 	gtk_widget_get_pointer(area, &x, &y);
@@ -532,6 +532,58 @@ static GtkWidget *build_map(void)
 	return table;
 }
 
+/** Builds the comments tab.
+ * @return The comments tab.
+ */
+static GtkWidget *build_comments(void)
+{
+	GtkWidget *vbox;
+	GtkWidget *widget;
+
+	vbox = gtk_vbox_new(FALSE, 5);
+	widget = gtk_label_new_with_mnemonic("_Title");
+	gtk_widget_show(widget);
+	gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
+
+	game_title = gtk_entry_new();
+	gtk_widget_show(game_title);
+	gtk_box_pack_start(GTK_BOX(vbox), game_title, FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(widget), game_title);
+
+	widget = gtk_label_new_with_mnemonic("_Description");
+	gtk_widget_show(widget);
+	gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
+
+	game_description = scrollable_text_view_new();
+	gtk_widget_show(game_description);
+	gtk_box_pack_start(GTK_BOX(vbox), game_description, FALSE, FALSE,
+			   0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(widget),
+				      scrollable_text_view_get_for_mnemonic
+				      (SCROLLABLE_TEXT_VIEW
+				       (game_description)));
+
+	scrollable_text_view_set_text(SCROLLABLE_TEXT_VIEW
+				      (game_description), "");
+
+	widget = gtk_label_new_with_mnemonic("_Comments");
+	gtk_widget_show(widget);
+	gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
+
+	game_comments = scrollable_text_view_new();
+	gtk_widget_show(game_comments);
+	gtk_box_pack_start(GTK_BOX(vbox), game_comments, TRUE, TRUE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(widget),
+				      scrollable_text_view_get_for_mnemonic
+				      (SCROLLABLE_TEXT_VIEW
+				       (game_comments)));
+
+	return vbox;
+}
+
 static gint select_terrain_cb(G_GNUC_UNUSED GtkWidget * menu,
 			      gpointer user_data)
 {
@@ -862,25 +914,28 @@ static void set_window_title(const gchar * title)
 
 	gtk_window_set_title(GTK_WINDOW(toplevel), str);
 	g_free(str);
+
+	gtk_entry_set_text(GTK_ENTRY(game_title), window_title);
 }
 
-static void apply_params(GameParams * params)
+static void apply_params(const GameParams * params)
 {
 	gint i;
 
 	set_window_title(params->title);
 
 	game_rules_set_random_terrain(game_rules, params->random_terrain);
-	game_rules_set_sevens_rule(game_rules, params->sevens_rule);
-	/* Do not disable the pirate rule if currently no ships are present */
-	game_rules_set_use_pirate(game_rules, params->use_pirate, 1);
 	game_rules_set_strict_trade(game_rules, params->strict_trade);
 	game_rules_set_domestic_trade(game_rules, params->domestic_trade);
-
 	game_settings_set_players(game_settings, params->num_players);
+	game_rules_set_sevens_rule(game_rules, params->sevens_rule);
 	game_settings_set_victory_points(game_settings,
 					 params->victory_points);
-
+	/* check_victory_at_end_of_turn not needed in the editor */
+	for (i = 1; i < NUM_BUILD_TYPES; i++)
+		game_buildings_set_num_buildings(game_buildings, i,
+						 params->num_build_type
+						 [i]);
 	game_resources_set_num_resources(game_resources,
 					 params->resource_count);
 
@@ -888,15 +943,23 @@ static void apply_params(GameParams * params)
 		game_devcards_set_num_cards(game_devcards, i,
 					    params->num_develop_type[i]);
 
-	for (i = 1; i < NUM_BUILD_TYPES; i++)
-		game_buildings_set_num_buildings(game_buildings, i,
-						 params->num_build_type
-						 [i]);
-
-	gmap->map = params->map;
+	/* Do not disable the pirate rule if currently no ships are present */
+	game_rules_set_use_pirate(game_rules, params->use_pirate, 1);
+	game_rules_set_island_discovery_bonus(game_rules,
+					      params->island_discovery_bonus);
+	scrollable_text_view_set_text(SCROLLABLE_TEXT_VIEW(game_comments),
+				      params->comments);
+	scrollable_text_view_set_text(SCROLLABLE_TEXT_VIEW
+				      (game_description),
+				      params->description);
 
+	map_free(gmap->map);
+	gmap->map = map_copy(params->map);
 }
 
+/** Returns params found in game_rules, game_settings, and other settings.
+ *  @return Params found in settings.
+ */
 static GameParams *get_params(void)
 {
 	GameParams *params = params_new();
@@ -905,35 +968,40 @@ static GameParams *get_params(void)
 	params->title = g_strdup(window_title);
 
 	params->random_terrain = game_rules_get_random_terrain(game_rules);
-	params->sevens_rule = game_rules_get_sevens_rule(game_rules);
-	params->use_pirate = game_rules_get_use_pirate(game_rules);
 	params->strict_trade = game_rules_get_strict_trade(game_rules);
 	params->domestic_trade = game_rules_get_domestic_trade(game_rules);
-
 	params->num_players = game_settings_get_players(game_settings);
+	params->sevens_rule = game_rules_get_sevens_rule(game_rules);
 	params->victory_points =
 	    game_settings_get_victory_points(game_settings);
 
-	params->resource_count =
-	    game_resources_get_num_resources(game_resources);
-
-	for (i = 0; i < NUM_DEVEL_TYPES; i++)
-		params->num_develop_type[i] =
-		    game_devcards_get_num_cards(game_devcards, i);
-
+	/* check_victory_at_end_of_turn not needed in the editor */
 	for (i = 1; i < NUM_BUILD_TYPES; i++)
 		params->num_build_type[i] =
 		    game_buildings_get_num_buildings(game_buildings, i);
+	params->resource_count =
+	    game_resources_get_num_resources(game_resources);
+	for (i = 0; i < NUM_DEVEL_TYPES; i++)
+		params->num_develop_type[i] =
+		    game_devcards_get_num_cards(game_devcards, i);
+	params->use_pirate = game_rules_get_use_pirate(game_rules);
+	params->island_discovery_bonus =
+	    game_rules_get_island_discovery_bonus(game_rules);
+	params->comments =
+	    scrollable_text_view_get_text(SCROLLABLE_TEXT_VIEW
+					  (game_comments));
+	params->description =
+	    scrollable_text_view_get_text(SCROLLABLE_TEXT_VIEW
+					  (game_description));
 
-	params->map = gmap->map;
-
+	params->map = map_copy(gmap->map);
 	return params;
 }
 
 static void load_game(const gchar * file, gboolean is_reload)
 {
 	const gchar *gamefile;
-	GameParams *new_params;
+	GameParams *params;
 	gchar *new_filename;
 	gint i;
 
@@ -942,29 +1010,29 @@ static void load_game(const gchar * file, gboolean is_reload)
 	else
 		gamefile = file;
 
-	new_params = params_load_file(gamefile);
-	if (new_params == NULL) {
+	params = params_load_file(gamefile);
+	if (params == NULL) {
 		error_dialog(_("Failed to load '%s'"), file);
 		return;
 	}
 
 	if (file == NULL) {
-		g_free(new_params->title);
-		new_params->title = g_strdup("Untitled");
-		map_free(new_params->map);
-		new_params->map = map_new();
+		g_free(params->title);
+		params->title = g_strdup("Untitled");
+		map_free(params->map);
+		params->map = map_new();
 		for (i = 0; i < 6; i++) {
-			map_modify_row_count(new_params->map,
+			map_modify_row_count(params->map,
 					     MAP_MODIFY_INSERT,
 					     MAP_MODIFY_ROW_BOTTOM);
 		}
 		for (i = 0; i < 11; i++) {
-			map_modify_column_count(new_params->map,
+			map_modify_column_count(params->map,
 						MAP_MODIFY_INSERT,
 						MAP_MODIFY_COLUMN_RIGHT);
 		}
-		new_params->map->chits =
-		    g_array_new(FALSE, FALSE, sizeof(gint));
+		/* Chits array will be constructed later */
+		params->map->chits = NULL;
 		new_filename = NULL;
 	} else {
 		new_filename = g_strdup(file);
@@ -972,10 +1040,9 @@ static void load_game(const gchar * file, gboolean is_reload)
 	}
 
 	guimap_reset(gmap);
-	if (params != NULL)
-		params_free(params);
-	params = new_params;
 	apply_params(params);
+	params_free(params);
+
 	if (open_filename != NULL)
 		g_free(open_filename);
 	open_filename = new_filename;
@@ -990,13 +1057,13 @@ static void load_game(const gchar * file, gboolean is_reload)
 
 static void save_game(const gchar * file)
 {
-	params = get_params();
-	canonicalize_map(gmap->map);
+	GameParams *params = get_params();
+	canonicalize_map(params->map);
 	if (!params_write_file(params, file))
 		error_dialog(_("Failed to save to '%s'"), file);
 	else
 		config_set_string("editor/last-game", file);
-	fill_map(gmap->map);
+	params_free(params);
 }
 
 static void new_game_menu_cb(void)
@@ -1004,9 +1071,27 @@ static void new_game_menu_cb(void)
 	load_game(NULL, TRUE);
 }
 
+static void add_file_filter(GtkFileChooser * file_chooser)
+{
+	GtkFileFilter *filter;
+
+	filter = gtk_file_filter_new();
+	/* Name of the file filter: show only games */
+	gtk_file_filter_set_name(filter, _("Games"));
+	gtk_file_filter_add_pattern(filter, "*.game");
+	gtk_file_chooser_add_filter(file_chooser, filter);
+
+	filter = gtk_file_filter_new();
+	/* Name of the file filter: show all files */
+	gtk_file_filter_set_name(filter, _("Unfiltered"));
+	gtk_file_filter_add_pattern(filter, "*");
+	gtk_file_chooser_add_filter(file_chooser, filter);
+}
+
 static void load_game_menu_cb(void)
 {
 	GtkWidget *dialog;
+	gchar *directory;
 
 	dialog = gtk_file_chooser_dialog_new(
 						    /* Dialog caption */
@@ -1017,8 +1102,18 @@ static void load_game_menu_cb(void)
 						    GTK_RESPONSE_CANCEL,
 						    GTK_STOCK_OPEN,
 						    GTK_RESPONSE_OK, NULL);
+	directory =
+	    g_build_filename(g_get_user_data_dir(), "pioneers", NULL);
+	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),
+					    directory);
+	gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(dialog),
+					     directory, NULL);
+	gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(dialog),
+					     get_pioneers_dir(), NULL);
+	g_free(directory);
 	gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog),
 				      default_game);
+	add_file_filter(GTK_FILE_CHOOSER(dialog));
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
 		char *file;
 		file =
@@ -1035,6 +1130,7 @@ static void load_game_menu_cb(void)
 static void save_as_menu_cb(void)
 {
 	GtkWidget *dialog;
+	gchar *directory;
 
 	dialog = gtk_file_chooser_dialog_new(
 						    /* Dialog caption */
@@ -1046,6 +1142,14 @@ static void save_as_menu_cb(void)
 						    GTK_STOCK_SAVE,
 						    GTK_RESPONSE_ACCEPT,
 						    NULL);
+	directory =
+	    g_build_filename(g_get_user_data_dir(), "pioneers", NULL);
+	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),
+					    directory);
+	gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(dialog),
+					     directory, NULL);
+	g_free(directory);
+	add_file_filter(GTK_FILE_CHOOSER(dialog));
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog),
 					GTK_RESPONSE_ACCEPT);
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
@@ -1089,10 +1193,10 @@ static void change_title_menu_cb(void)
 	g_signal_connect(G_OBJECT(dialog), "destroy",
 			 G_CALLBACK(gtk_widget_destroyed), &dialog);
 	gtk_widget_realize(dialog);
-	gdk_window_set_functions(dialog->window,
+	gdk_window_set_functions(gtk_widget_get_window(dialog),
 				 GDK_FUNC_MOVE | GDK_FUNC_CLOSE);
 
-	vbox = GTK_DIALOG(dialog)->vbox;
+	vbox = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
@@ -1124,6 +1228,7 @@ static void check_vp_cb(G_GNUC_UNUSED GObject * caller,
 
 	params = get_params();
 	check_victory_points(params, main_window);
+	params_free(params);
 }
 
 static void exit_cb(void)
@@ -1332,6 +1437,9 @@ int main(int argc, char *argv[])
 	default_game = g_build_filename(get_pioneers_dir(), "default.game",
 					NULL);
 
+	/* set the UI driver to GTK_Driver, since we're using gtk */
+	set_ui_driver(&GTK_Driver);
+
 	/* Gtk+ handles the locale, we must bind the translations */
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
@@ -1415,6 +1523,9 @@ int main(int argc, char *argv[])
 				 build_settings(GTK_WINDOW(toplevel)),
 				 /* Tab page name */
 				 gtk_label_new(_("Settings")));
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), build_comments(),
+				 /* Tab page name */
+				 gtk_label_new(_("Comments")));
 
 	terrain_menu = build_terrain_menu();
 	roll_menu = build_roll_menu();
@@ -1439,8 +1550,6 @@ int main(int argc, char *argv[])
 
 	load_game(filename, FALSE);
 	g_free(filename);
-	if (params == NULL)
-		return 1;
 
 	gtk_widget_show_all(toplevel);
 
@@ -1451,5 +1560,6 @@ int main(int argc, char *argv[])
 	g_free(default_game);
 
 	g_option_context_free(context);
+	themes_cleanup();
 	return 0;
 }
