@@ -174,8 +174,8 @@ gboolean mode_road_building(Player * player, gint event)
 		/* Send ack to client, check for victory, and quit.
 		 */
 		player_send(player, FIRST_VERSION, LATEST_VERSION, "OK\n");
-		check_victory(player);
 		sm_pop(sm);
+		check_victory(player);
 		return TRUE;
 	}
 
@@ -294,7 +294,6 @@ gboolean mode_monopoly(Player * player, gint event)
 	if (!sm_recv(sm, "monopoly %r", &type))
 		return FALSE;
 
-	player_send(player, FIRST_VERSION, LATEST_VERSION, "OK\n");
 	/* Now inform the various parties of the monopoly.
 	 */
 	for (list = player_first_real(game);
@@ -314,6 +313,7 @@ gboolean mode_monopoly(Player * player, gint event)
 		player->assets[type] += scan->assets[type];
 		scan->assets[type] = 0;
 	}
+	player_send(player, FIRST_VERSION, LATEST_VERSION, "OK\n");
 
 	sm_pop(sm);
 	return TRUE;
@@ -369,7 +369,7 @@ void develop_play(Player * player, gint idx)
 	Game *game = player->game;
 	DevelType card;
 
-	if (idx >= player->devel->num_cards) {
+	if (idx >= player->devel->num_cards || idx < 0) {
 		player_send(player, FIRST_VERSION, LATEST_VERSION,
 			    "ERR no-card\n");
 		return;
