@@ -38,6 +38,7 @@ static void check_finished_discard(Game * game, gboolean was_discard)
 	 * actually was a discarding phase */
 	if (was_discard)
 		player_broadcast(player_none(game), PB_SILENT,
+				 FIRST_VERSION, LATEST_VERSION,
 				 "discard-done\n");
 	/* everyone is done discarding, pop all the state machines to their
 	 * original state and push the robber to whoever wants it. */
@@ -81,7 +82,8 @@ gboolean mode_discard_resources(Player * player, gint event)
 		num += discards[idx];
 	if (num != player->discard_num
 	    || !cost_can_afford(discards, player->assets)) {
-		sm_send(sm, "ERR wrong-discard\n");
+		player_send(player, FIRST_VERSION, LATEST_VERSION,
+			    "ERR wrong-discard\n");
 		return TRUE;
 	}
 
@@ -120,7 +122,7 @@ void discard_resources(Game * game)
 			if (scan->assets[idx] > 0)
 				++num_types;
 		}
-		if (num > 7) {
+		if (num > 7 + scan->num_city_walls * 2) {
 			scan->discard_num = num / 2;
 			/* discard random resources of disconnected players */
 			/* also do auto-discard if there is no choice */
@@ -146,6 +148,8 @@ void discard_resources(Game * game)
 					++game->bank_deck[idx];
 				}
 				player_broadcast(scan, PB_ALL,
+						 FIRST_VERSION,
+						 LATEST_VERSION,
 						 "discarded %R\n",
 						 resource);
 				/* push idle to be popped off when all
@@ -157,6 +161,8 @@ void discard_resources(Game * game)
 				sm_push(scan->sm, (StateFunc)
 					mode_discard_resources);
 				player_broadcast(scan, PB_ALL,
+						 FIRST_VERSION,
+						 LATEST_VERSION,
 						 "must-discard %d\n",
 						 scan->discard_num);
 			}
