@@ -197,6 +197,8 @@ static void update_game_settings(const GameParams * params)
 	game_rules_set_use_pirate(GAMERULES(game_rules),
 				  params->use_pirate,
 				  params->num_build_type[BUILD_SHIP]);
+	game_rules_set_island_discovery_bonus(GAMERULES(game_rules),
+					      params->island_discovery_bonus);
 }
 
 static void game_activate(GtkWidget * widget,
@@ -266,6 +268,12 @@ static void start_clicked_cb(G_GNUC_UNUSED GtkButton * widget,
 		    game_rules_get_use_pirate(GAMERULES(game_rules));
 		params->domestic_trade =
 		    game_rules_get_domestic_trade(GAMERULES(game_rules));
+		if (params->island_discovery_bonus) {
+			g_array_free(params->island_discovery_bonus, TRUE);
+		}
+		params->island_discovery_bonus =
+		    game_rules_get_island_discovery_bonus(GAMERULES
+							  (game_rules));
 		update_game_settings(params);
 
 		meta_server_name = metaserver_get(METASERVER(meta_entry));
@@ -339,7 +347,7 @@ static void launchclient_clicked_cb(G_GNUC_UNUSED GtkButton * widget,
 			   NULL, NULL, NULL, &error)) {
 		/* Error message when program %1 is started, reason is %2 */
 		log_message(MSG_ERROR,
-			    _("Error starting %s: %s"),
+			    _("Error starting %s: %s\n"),
 			    PIONEERS_CLIENT_GTK_PATH, error->message);
 		g_error_free(error);
 	}
@@ -556,8 +564,6 @@ static GtkWidget *build_server_frame(void)
 				      "Register this game at the meta server"));
 	register_server =
 	    config_get_int_with_default("server/register", TRUE);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle),
-				     register_server);
 
 	/* meta server label */
 	label = gtk_label_new(_("Meta server"));
@@ -616,6 +622,9 @@ static GtkWidget *build_server_frame(void)
 	gtk_entry_set_text(GTK_ENTRY(overridden_hostname_entry),
 			   overridden_hostname);
 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle),
+				     register_server);
+
 	/* random toggle */
 	toggle = gtk_check_button_new_with_label(_("Random turn order"));
 	gtk_widget_show(toggle);
@@ -698,47 +707,44 @@ static GtkWidget *build_connected_tree_view(void)
 				    _(""
 				      "Shows all players and spectators connected to the server"));
 
-	/* connected column */
 	column =
+	    /* Label for column Connected */
 	    gtk_tree_view_column_new_with_attributes(_("Connected"),
 						     gtk_cell_renderer_toggle_new
 						     (), "active",
 						     PLAYER_COLUMN_CONNECTED,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), column);
-	gtk_widget_set_tooltip_text(column->button,
-				    /* Tooltip for column Connected */
-				    _(""
-				      "Is the player currently connected?"));
+	/* Tooltip for column Connected */
+	set_tooltip_on_column(column, _(""
+					"Is the player currently connected?"));
 
-	/* name column */
 	column =
+	    /* Label for column Name */
 	    gtk_tree_view_column_new_with_attributes(_("Name"),
 						     gtk_cell_renderer_text_new
 						     (), "text",
 						     PLAYER_COLUMN_NAME,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), column);
-	gtk_widget_set_tooltip_text(column->button,
-				    /* Tooltip for column Name */
-				    _("Name of the player"));
+	/* Tooltip for column Name */
+	set_tooltip_on_column(column, _("Name of the player"));
 
-	/* location column */
 	column =
+	    /* Label for column Location */
 	    gtk_tree_view_column_new_with_attributes(_("Location"),
 						     gtk_cell_renderer_text_new
 						     (), "text",
 						     PLAYER_COLUMN_LOCATION,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), column);
-	gtk_widget_set_tooltip_text(column->button,
-				    /* Tooltip for column Location */
-				    _("Host name of the player"));
+	/* Tooltip for column Location */
+	set_tooltip_on_column(column, _("Host name of the player"));
 
 	renderer = gtk_cell_renderer_text_new();
 
-	/* number column */
 	column =
+	    /* Label for column Number */
 	    gtk_tree_view_column_new_with_attributes(_("Number"), renderer,
 						     "text",
 						     PLAYER_COLUMN_NUMBER,
@@ -746,18 +752,17 @@ static GtkWidget *build_connected_tree_view(void)
 	g_object_set(renderer, "xalign", 1.0f, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), column);
 	/* Tooltip for column Number */
-	gtk_widget_set_tooltip_text(column->button, _("Player number"));
+	set_tooltip_on_column(column, _("Player number"));
 
 	renderer = gtk_cell_renderer_text_new();
 
-	/* role column */
 	column =
+	    /* Label for column Role */
 	    gtk_tree_view_column_new_with_attributes(_("Role"), renderer,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), column);
 	/* Tooltip for column Role */
-	gtk_widget_set_tooltip_text(column->button,
-				    _("Player or spectator"));
+	set_tooltip_on_column(column, _("Player or spectator"));
 
 	gtk_tree_view_column_set_cell_data_func(column, renderer,
 						my_cell_player_spectator_to_text,
@@ -1080,6 +1085,11 @@ static void check_vp_cb(G_GNUC_UNUSED GObject * caller,
 	    game_rules_get_use_pirate(GAMERULES(game_rules));
 	params->domestic_trade =
 	    game_rules_get_domestic_trade(GAMERULES(game_rules));
+	if (params->island_discovery_bonus) {
+		g_array_free(params->island_discovery_bonus, TRUE);
+	}
+	params->island_discovery_bonus =
+	    game_rules_get_island_discovery_bonus(GAMERULES(game_rules));
 	update_game_settings(params);
 
 	check_victory_points(params, main_window);
@@ -1245,5 +1255,6 @@ int main(int argc, char *argv[])
 	net_finish();
 	g_option_context_free(context);
 	game_list_cleanup();
+	themes_cleanup();
 	return 0;
 }
