@@ -150,7 +150,7 @@ gint add_computer_player(Game * game, gboolean want_chat)
 	if (!g_spawn_async(NULL, child_argv, NULL, 0, NULL, NULL,
 			   NULL, &error)) {
 		log_message(MSG_ERROR,
-			    _("Error starting %s: %s"),
+			    _("Error starting %s: %s\n"),
 			    PIONEERS_AI_PATH, error->message);
 		g_error_free(error);
 		ret = -1;
@@ -308,6 +308,11 @@ static gboolean game_list_add_item(GameParams * item)
 		gchar *nt;
 		gint i;
 
+		if (params_is_equal
+		    (item, game_list_find_item(item->title))) {
+			return FALSE;
+		}
+
 		/* append a number */
 		for (i = 1; i <= INT_MAX; i++) {
 			nt = g_strdup_printf("%s%d", item->title, i);
