@@ -28,21 +28,6 @@
 #include "quoteinfo.h"
 #include "state.h"
 
-/* Supported versions.  These are ordered, so that it is possible to see
- * if versions are greater or smaller than each other.  The actual values do
- * not matter and will change when older versions stop being supported.  No
- * part of the program may depend on their exact value, all comparisons must
- * always be done with the symbols.  */
-/* Names for the versions are defined in server/player.c, and must be
- * changed when the enum changes.  */
-typedef enum {
-	V0_10, /**< Lowest supported version */
-	V0_11, /**< City walls, player style, robber undo */
-	V0_12, /**< Trade protocol simplified */
-	FIRST_VERSION = V0_10,
-	LATEST_VERSION = V0_12
-} ClientVersionType;
-
 #define TERRAIN_DEFAULT	0
 #define TERRAIN_RANDOM	1
 
@@ -74,7 +59,6 @@ typedef struct {
 	gint num_city_walls;	/* city walls available */
 
 	gint num_soldiers;	/* number of soldiers played */
-	gint road_len;		/* last longest road */
 	gint develop_points;	/* number of development card victory points */
 	gint chapel_played;	/* number of Chapel cards played */
 	gint univ_played;	/* number of University cards played */
@@ -136,7 +120,7 @@ struct Game {
 
 /**** global variables ****/
 /* buildutil.c */
-void check_longest_road(Game * game, gboolean can_cut);
+void check_longest_road(Game * game);
 void node_add(Player * player,
 	      BuildType type, int x, int y, int pos, gboolean paid_for,
 	      Points * special_points);
